@@ -1,6 +1,6 @@
 <?php
 /**
- * Show admin page
+ * Display admin page
  *
  * This file is part of Zoph.
  *
@@ -21,19 +21,17 @@
  * @author Jeroen Roos
  */
 
-use template\template;
+use conf\conf;
+use admin\controller;
+use web\redirect;
+use web\request;
 
 require_once "include.inc.php";
 
 if (!$user->isAdmin()) {
-    redirect("zoph.php");
+    redirect::redirect("zoph.php", "Admin user required");
 }
-$title=translate("Adminpage");
-$adminpages=admin::getArray();
 
-$tpl=new template("admin", array(
-    "title" => $title,
-    "adminpages" => $adminpages
-));
-echo $tpl;
-?>
+$ctrl = new controller(request::create());
+$view = $ctrl->getView();
+$view->display();
