@@ -31,8 +31,13 @@
 use conf\conf;
 use auth\web;
 use auth\cli;
-use web\session;
+use web\redirect;
 use web\request;
+use web\session;
+
+if (defined("LOGON") || defined("TEST") || defined("INSTALL")) {
+    return;
+}
 
 $error="";
 $_action="display";
@@ -58,7 +63,7 @@ if ($user instanceof user) {
     $_action = $request["_action"];
 }
 if ($auth->getRedirect()) {
-    redirect($auth->getRedirect());
+    redirect::redirect($auth->getRedirect());
 }
 
 ?>
