@@ -39,7 +39,7 @@ use template\template;
  * @author Jason Geiger
  * @author Jeroen Roos
  */
-class album extends zophTreeTable implements Organizer {
+class album extends zophTreeTable implements organizer {
 
     use showPage;
 
@@ -58,7 +58,7 @@ class album extends zophTreeTable implements Organizer {
                   are set by the db with auto_increment */
     protected static $keepKeys = false;
     /** @var string URL for this class */
-    protected static $url="albums.php?parent_album_id=";
+    protected static $url="album.php?album_id=";
 
     /** @var int Cache the count of photos */
     private $photoCount;
@@ -235,26 +235,12 @@ class album extends zophTreeTable implements Organizer {
     public function getDetails() {
         $user=user::getCurrent();
 
-        $qry=new select(array("pa" => "photo_albums"));
-        $qry->addFunction(array(
-            "count"     => "COUNT(DISTINCT p.photo_id)",
-            "oldest"    => "MIN(DATE_FORMAT(CONCAT_WS(' ',p.date,p.time), GET_FORMAT(DATETIME, 'ISO')))",
-            "newest"    => "MAX(DATE_FORMAT(CONCAT_WS(' ',p.date,p.time), GET_FORMAT(DATETIME, 'ISO')))",
-            "first"     => "MIN(p.timestamp)",
-            "last"      => "MAX(p.timestamp)",
-            "lowest"    => "ROUND(MIN(ar.rating),1)",
-            "highest"   => "ROUND(MAX(ar.rating),1)",
-            "average"   => "ROUND(AVG(ar.rating),2)"));
-        $qry->join(array("p" => "photos"), "pa.photo_id = p.photo_id")
-            ->join(array("ar" => "view_photo_avg_rating"), "p.photo_id = ar.photo_id");
-
-        $qry->addGroupBy("pa.album_id");
-
-        $where=new clause("pa.album_id=:albid");
+        $qry=new select(array("vad" => "view_albums_details"));
+        $where=new clause("vad.album_id=:albid");
         $qry->addParam(new param(":albid", $this->getId(), PDO::PARAM_INT));
 
         if (!$user->canSeeAllPhotos()) {
-            $qry->join(array("gp" => "group_permissions"), "pa.album_id=gp.album_id")
+            $qry->join(array("gp" => "group_permissions"), "vad.album_id=gp.album_id")
                 ->join(array("gu" => "groups_users"), "gp.group_id=gu.group_id");
             $where->addAnd(new clause("gu.user_id=:userid"));
             $qry->addParam(new param(":userid", (int) $user->getId(), PDO::PARAM_INT));
@@ -267,7 +253,7 @@ class album extends zophTreeTable implements Organizer {
         if ($result) {
             return $result->fetch(PDO::FETCH_ASSOC);
         } else {
-            return null;
+            return array();
         }
     }
 
@@ -275,10 +261,11 @@ class album extends zophTreeTable implements Organizer {
      * Turn the array from @see getDetails() into XML
      * @param array Don't fetch details, but use the given array
      */
-    public function getDetailsXML(array $details=null) {
-        if (!isset($details)) {
+    public function getDetailsXML(array $details = array()) {
+        if (empty($details)) {
             $details=$this->getDetails();
         }
+
         $details["title"]=translate("In this album:", false);
         return parent::getDetailsXML($details);
     }
@@ -353,33 +340,31 @@ class album extends zophTreeTable implements Organizer {
         } else {
             $parent=array (
                 translate("parent album"),
-                static::createPulldown("parent_album_id", $this->get("parent_album_id")));
+                static::createDropdown("parent_album_id", $this->get("parent_album_id")));
         }
         return array(
             "album" =>
                 array(
                     translate("album name"),
-                    create_text_input("album", $this->get("album"),40,64)),
+                    template::createInput("album", $this->get("album"),64, null, 40)),
             "parent_album_id" => $parent,
             "album_description" =>
                 array(
                     translate("album description"),
-                    create_text_input("album_description",
-                        $this->get("album_description"), 40, 128)),
+                    template::createInput("album_description", $this->get("album_description"), 128, null, 40)),
             "pageset" =>
                 array(
                     translate("pageset"),
-                    template::createPulldown("pageset", $this->get("pageset"),
+                    template::createDropdown("pageset", $this->get("pageset"),
                         template::createSelectArray(pageset::getRecords("title"), array("title"), true))),
             "sortname" =>
                 array(
                     translate("sort name"),
-                    create_text_input("sortname",
-                        $this->get("sortname"))),
+                    template::createInput("sortname", $this->get("sortname"))),
             "sortorder" =>
                 array(
                     translate("album sort order"),
-                    template::createPhotoFieldPulldown("sortorder", $this->get("sortorder")))
+                    template::createPhotoFieldDropdown("sortorder", $this->get("sortorder")))
         );
     }
 
