@@ -35,20 +35,25 @@ use user;
 
 use albumNotAccessibleSecurityException;
 
+use organiserActions;
 
 /**
  * Controller for album
  */
 class controller extends genericController {
+    use organiserActions;
+
+    protected static $viewConfirm   = view\confirm::class;
+    protected static $viewDisplay   = view\display::class;
+    protected static $viewNew       = view\update::class;
+    protected static $viewNotfound  = view\notfound::class;
+    protected static $viewUpdate    = view\update::class;
 
     /** @var array Actions that can be used in this controller */
     protected   $actions    = array(
         "new", "insert", "confirm", "delete", "display", "edit", "update", "coverphoto", "unsetcoverphoto"
     );
 
-    /** @var string Where to redirect after actions */
-    public $redirect="albums.php";
-
     /**
      * Create a controller using a web request
      * @param request request
@@ -73,7 +78,7 @@ class controller extends genericController {
                 $this->setObject($album);
                 $this->doAction();
             } else {
-                $this->view = "notfound";
+                $this->view = new  static::$viewNotfound($this->request, $this->object);
             }
         }
     }
@@ -92,11 +97,11 @@ class controller extends genericController {
         } else {
             $album=album::getRoot();
         }
-        if ($user->isAdmin() || $user->getAlbumPermissions($album)) {
+        if ($album && ($user->isAdmin() || $user->getAlbumPermissions($album))) {
             return $album;
         }
         throw new albumNotAccessibleSecurityException(
-            "Security Exception: album " . $album->getId() .
+            "Security Exception: album " .  (int) $this->request["album_id"] .
             " is not accessible for user " . $user->getName() . " (" . $user->getId() . ")"
         );
     }
@@ -106,9 +111,11 @@ class controller extends genericController {
      */
     public function actionConfirm() {
         if (user::getCurrent()->canDeletePhotos()) {
+            $parentId = $this->object->get("parent_album_id");
             parent::actionConfirm();
+            $this->view->setRedirect("album.php?album_id=" . $parentId);
         } else {
-            $this->view="display";
+            $this->actionDisplay();
         }
     }
 
@@ -119,37 +126,28 @@ class controller extends genericController {
         if (user::getCurrent()->canDeletePhotos()) {
             parent::actionDelete();
         } else {
-            $this->view="display";
+            $this->actionDisplay();
         }
     }
 
-    /**
-     * Do action 'display'
-     */
-    public function actionDisplay() {
-        $user = user::getCurrent();
-        $this->view="display";
-    }
-
     /**
      * Do action 'edit'
      */
     public function actionEdit() {
         $user = user::getCurrent();
         if ($this->object->isWritableBy($user)) {
-            $this->view="update";
+            $this->view = new static::$viewUpdate($this->request, $this->object);
         } else {
-            $this->view="display";
+            $this->actionDisplay();
         }
     }
 
     /**
-     * Do action 'new'
+     * Do action 'insert'
      */
     public function actionInsert() {
         parent::actionInsert();
-        $this->redirect="album.php?_action=edit&album_id=" . $this->object->getId();
-        $this->view="redirect";
+        $this->view = new static::$viewUpdate($this->request, $this->object);
     }
 
     /**
@@ -158,9 +156,9 @@ class controller extends genericController {
     public function actionNew() {
         $user = user::getCurrent();
         if ($user->canEditOrganizers()) {
-            $this->view="update";
+            $this->view = new static::$viewUpdate($this->request, $this->object);
         } else {
-            $this->view="display";
+            $this->actionDisplay();
         }
     }
 
@@ -172,27 +170,10 @@ class controller extends genericController {
         if ($this->object->isWritableBy($user)) {
             $this->object->setFields($this->request->getRequestVars());
             $this->object->update();
-            redirect("album.php?action=edit&amp;album_id=" . $this->object->getId(), "Update done");
+            $this->view = new static::$viewUpdate($this->request, $this->object);
+        } else {
+            $this->actionDisplay();
         }
-        $this->view="display";
-    }
-
-    public function actionCoverphoto() {
-        $user=user::getCurrent();
-        if ($this->object->isWritableBy($user) && isset($this->request["coverphoto"])) {
-            $this->object->set("coverphoto", (int) $this->request["coverphoto"]);
-            $this->object->update();
-        }
-        $this->view="redirect";
-    }
-
-    public function actionUnsetcoverphoto() {
-        $user=user::getCurrent();
-        if ($this->object->isWritableBy($user)) {
-            $this->object->set("coverphoto", null);
-            $this->object->update();
-        }
-        $this->view="redirect";
     }
 
 }
