@@ -23,7 +23,7 @@
 
 namespace album\view;
 
-use template\template;
+use template\block;
 use web\request;
 use photo;
 use user;
@@ -34,27 +34,25 @@ use album;
  */
 class confirm extends view {
 
-
     /**
      * Get actionlinks
      */
-    public function getActionlinks() {
+    public function getActionlinks() : ?array {
         return array(
-            translate("confirm")   =>  "album.php?_action=confirm&amp;album_id=" . $this->album->getId(),
-            translate("cancel")    =>  "albums.php?parent_album_id=" . $this->album->getId()
+            translate("confirm")   =>  "album.php?_action=confirm&amp;album_id=" . $this->object->getId(),
+            translate("cancel")    =>  "album.php?album_id=" . $this->object->getId()
         );
 
     }
     /**
      * Output view
      */
-    public function view() {
-        return new template("confirm", array(
-            "title"     =>  translate("delete album"),
+    public function view() : block {
+        return new block("confirm", array(
+            "title"         =>  translate("delete album"),
             "actionlinks"   => $this->getActionlinks(),
             "mainActionlinks" => null,
-            "obj"           => $this->album,
+            "obj"           => $this->object,
         ));
-
     }
 }
