@@ -26,10 +26,10 @@
  * @author Jeroen Roos
  */
 
+use user\prefs;
 /**
  * @todo These requires should be removed once all classes can be autoloaded
  */
-require_once "util.inc.php";
 require_once "variables.inc.php";
 
 /**
