@@ -63,7 +63,6 @@ class web implements auth {
         $migrations=false;
         $this->redirect="logon.php";
         $this->lang = new language(conf::get("interface.language"));
-
         if (isset($this->session['user'])) {
             $this->user = $this->session['user'];
         }
@@ -193,7 +192,7 @@ class web implements auth {
         } else {
             $uname = $this->request["uname"];
             $pword = $this->request["pword"];
-            if (!empty($uname)) {
+            if (!empty($uname) || conf::get("interface.user.default") !== "0") {
                 $validator = new validator($uname, $pword);
                 $user = $validator->validate();
             }
@@ -233,7 +232,8 @@ class web implements auth {
      * @param string error code to pass
      */
     private function setRedirectLogon($error = null) {
-        $thisPage=urlencode(preg_replace("/^\//", "", $this->request->getServerVar("REQUEST_URI")));
+        $request=$this->request->getServerVar("REQUEST_URI");
+        $thisPage=$request ? urlencode(preg_replace("/^\//", "", $request)) : "";
         if (strstr($thisPage, "service%2F")) {
             $page = "../logon.php";
         } else {
