@@ -28,36 +28,25 @@ use template\block;
 use template\form;
 use template\template;
 use web\request;
+use web\view\view;
 
 /**
  * Display screen to start backup
  */
-class display {
-
-    /** @var request hold the request for this view */
-    private $request;
+class display extends view implements \view {
 
     /**
      * Create view
      * @param request web request
      */
-    public function __construct(request $request) {
-        $this->request=$request;
-    }
-
-    /**
-     * Get headers - always null, so default headers will be used
-     * @return null
-     */
-    public function getHeaders() {
-        return null;
+    public function __construct(protected request $request) {
     }
 
     /**
      * Get view
      * @return template view
      */
-    public function view() {
+    public function view() : block {
         if (empty($this->request->getServerVar("HTTPS"))) {
             $warning = new block("message", array(
                 "class"  => "warning",
@@ -77,7 +66,7 @@ class display {
         $form->addInputPassword("rootpwd", translate("root password"), translate("leave empty to perform backup with normal Zoph database user"), 32, 16);
 
 
-        $tpl=new template("main-nh", array(
+        $tpl=new block("main", array(
             "title"         => $this->getTitle(),
         ));
 
@@ -95,7 +84,7 @@ class display {
      * Get title
      * @return string title
      */
-    public function getTitle() {
+    public function getTitle() : string {
         return translate("Create backup");
     }
 }
