@@ -26,25 +26,20 @@ use template\block;
 
 class breadcrumb {
 
-    /** @var string title of the crumb */
-    private $title;
-    /** @var string url of the crumb */
-    private $url;
     /** @var array Current breadcrumbs */
     private static $crumbs=array();
 
-    private static $actions=array("", "display", "search", "notify", "compose", "new");
+    private static $actions=array("", "display", "search", "notify", "compose", "new", "users", "comments", "groups", "sets", "pages", "pagesets");
 
     /**
      * Create a crumb
      * @param string title
      * @param string url
      */
-    public function __construct(string $title, string $url) {
-        $this->title=$title;
-        $this->url=$url;
+    public function __construct(private string $title, private string $url) {
     }
 
+
     /**
      * Create a crumb
      * Crumbs are the path a user followed through Zoph's web GUI and can be
@@ -55,14 +50,17 @@ class breadcrumb {
      * @param string action (display, edit, delete, etc.)
      * @todo calls $_SERVER directly
      */
-    public static function create($title, $action) {
+    public static function create($title, $action = "") {
+        if (is_null($action)) {
+            $action = "";
+        }
         $user=user::getCurrent();
         $url=htmlentities($_SERVER["REQUEST_URI"]);
         $page=array_reverse(explode("/", $_SERVER['PHP_SELF']));
         $page=$page[0];
 
         $allowed = ((in_array($action, self::$actions, true)) ||
-            ($user->prefs->get("auto_edit") && $page == "photo.php" && $action == "edit"));
+            ($user?->prefs->get("auto_edit") && $page == "photo.php" && $action == "edit"));
         $numCrumbs = count(static::$crumbs);
 
         if (isset($title) && $numCrumbs < 100 && $allowed && ($numCrumbs == 0 || (!strpos($url, "_crumb=")))) {
@@ -170,7 +168,7 @@ class breadcrumb {
     public static function display() {
         $user=user::getCurrent();
 
-        $max_crumbs=$user->prefs->get("num_breadcrumbs");
+        $max_crumbs=$user?->prefs->get("num_breadcrumbs") ?? 10;
         if (($num_crumbs = count(static::$crumbs)) > $max_crumbs) {
             $crumbs=array_slice(static::$crumbs, $num_crumbs - $max_crumbs);
             $class="firstdots";
