@@ -23,7 +23,7 @@
 
 namespace category\view;
 
-use template\template;
+use template\block;
 use web\request;
 use photo;
 use user;
@@ -34,26 +34,26 @@ use category;
  */
 class confirm extends view {
 
-
     /**
      * Get actionlinks
      */
-    public function getActionlinks() {
+    public function getActionlinks() : array {
         return array(
-            translate("confirm")   =>  "category.php?_action=confirm&amp;category_id=" . $this->category->getId(),
-            translate("cancel")    =>  "categories.php?parent_category_id=" . $this->category->getId()
+            translate("confirm")   =>  "category.php?_action=confirm&amp;category_id=" . $this->object->getId(),
+            translate("cancel")    =>  "category.php?category_id=" . $this->object->getId()
         );
 
     }
+
     /**
      * Output view
      */
-    public function view() {
-        return new template("confirm", array(
-            "title"     =>  translate("delete category"),
-            "actionlinks"   => $this->getActionlinks(),
-            "mainActionlinks" => null,
-            "obj"           => $this->category,
+    public function view() : block {
+        return new block("confirm", array(
+            "title"             =>  translate("delete category"),
+            "actionlinks"       => $this->getActionlinks(),
+            "mainActionlinks"   => null,
+            "obj"               => $this->object,
         ));
 
     }
