@@ -24,12 +24,18 @@ namespace cli;
 use log;
 use album;
 use category;
+use group;
 use person;
 use place;
 use user;
 
 use conf\conf;
 
+use userUnknownAccessRightException;
+use groupNotFoundException;
+use set\notFoundException as setNotFoundException;
+use set\model as set;
+
 /**
  * This class reads and interpretes CLI arguments
  */
@@ -78,6 +84,7 @@ class arguments {
         $args["people"]=array();
         $args["photographer"]=array();
         $args["location"]=array();
+        $args["sets"]=array();
         $args["instance"]="";
         $args["fields"]=array();
         $args["path"]="";
@@ -91,7 +98,7 @@ class arguments {
         $args["pplace"]=array();
 
         /*
-          Used short arguments: A C D H I N P U V X a c d f g h i l n p r t u v w
+          Used short arguments: A C D F H I N P U V X a c d f g h i l n p r s t u v w
         */
         $size=sizeof($argv);
         for ($i=0; $i<$size; $i++) {
@@ -104,17 +111,22 @@ class arguments {
                 break;
 
 
+            case "--add-access":
             case "--access":
                 $this->argsAddAccess(explode(",",$argv[++$i]));
                 break;
+            case "--revoke-access":
+            case "--remove-access":
             case "--no-access":
                 $this->argsRemoveAccess(explode(",",$argv[++$i]));
                 break;
             case "--admin":
                 $args["_admin"]=true;
+                $args["_no_admin"]=false;
                 break;
             case "--no-admin":
                 $args["_admin"]=false;
+                $args["_no_admin"]=true;
                 break;
 
             case "--albums":
@@ -145,9 +157,12 @@ class arguments {
             case "--dump-config":
                 static::$command="dumpconfig";
                 break;
+            case "-f":
+                $args["_force"]=true;
+                break;
             case "--fields":
             case "--field":
-            case "-f":
+            case "-F":
                 $args["fields"][]=$argv[++$i];
                 break;
             case "--getconfig":
@@ -156,11 +171,20 @@ class arguments {
                 static::$command="getconfig";
                 $args["_getconfigitem"]=$argv[++$i];
                 break;
+            case "--groups":
             case "--group":
             case "-G":
                 $groups=explode(",",$argv[++$i]);
                 foreach ($groups as $group) {
-                    $args["_groups"][]=trim($group);
+                    $args["_groups"][]=strtolower(trim($group));
+                }
+                break;
+            case "--no-group":
+            case "--remove-group":
+            case "--remove-groups":
+                $groups=explode(",",$argv[++$i]);
+                foreach ($groups as $group) {
+                    $args["_remove_groups"][]=strtolower(trim($group));
                 }
                 break;
             case "--place":
@@ -197,6 +221,13 @@ class arguments {
                 $args["_password"]=$argv[++$i];
                 break;
 
+            case "--sets":
+            case "--set":
+            case "-s":
+                $this->argsSets(explode(",",$argv[++$i]));
+                break;
+
+
             case "--thumbs":
             case "-t":
                 conf::set("import.cli.thumbs", true);
@@ -416,6 +447,13 @@ class arguments {
         }
     }
 
+    private function argsSets(array $sets) {
+        foreach ($sets as $set) {
+            $this->processed["sets"][]=trim($set);
+        }
+    }
+
+
     /**
      * Looks up the given parameters in the database and gives back ids
      */
@@ -444,6 +482,9 @@ class arguments {
             case "location":
                 $this->lookupLocations($arg, $args["pplace"]);
                 break;
+            case "sets":
+                $this->lookupSets($arg);
+                break;
             case "path":
                 $vars["_path"]=$arg;
                 break;
@@ -466,15 +507,30 @@ class arguments {
                 break;
             case "_admin":
                 $vars["_admin"] = (bool) $arg;
-
+                break;
+            case "_no_admin":
+                $vars["_no_admin"] = (bool) $arg;
+                break;
+            case "_force":
+                $vars["_force"] = (bool) $arg;
+                break;
             case "_add_access":
             case "_remove_access":
-                /** @todo: implement lookup of various access right */
+                foreach ($arg as $right) {
+                    if (!array_key_exists($right, user::getAccessRightsDescription())) {
+                        throw new userUnknownAccessRightException(e($right) . " is not a known access right");
+                    }
+                }
                 $vars[$type]=$arg;
                 break;
-            case "_group":
-                /** @todo: implement lookup of groups */
-                $vars["_group"]=$arg;
+            case "_groups":
+            case "_remove_groups":
+                foreach ($arg as $group) {
+                    if (!group::exists($group)) {
+                        throw new groupNotFoundException(e($group) . " is not a known group");
+                    }
+                }
+                $vars[$type]=$arg;
                 break;
             case "_password":
                 $vars["_password"]=$arg;
@@ -646,5 +702,17 @@ class arguments {
             }
         }
     }
+
+    private function lookupSets(array $sets) {
+        foreach ($sets as $name) {
+            $set=set::getByName($name);
+            if ($set) {
+                $this->vars["_set_id"][]=$set[0]->getId();
+            } else {
+                throw new setNotFoundException("Set not found: $name");
+            }
+        }
+    }
+
 }
 ?>
