@@ -22,21 +22,40 @@
 namespace cli;
 
 use album;
+use auth\validator;
 use category;
+use conf\conf;
 use file;
+use group;
+use import\cli as cliimport;
 use person;
 use photo;
 use place;
+use template\block;
 use user;
-
-use auth\validator;
-
-use conf\conf;
-
-use import\cli as cliimport;
-
-use xmp\reader as xmpreader;
 use xmp\decoder as xmpdecoder;
+use xmp\reader as xmpreader;
+
+use Exception;
+use albumNotFoundException;
+use categoryNotFoundException;
+use cliAPINotCompatibleException;
+use cliException;
+use cliNoFilesException;
+use cliNoPasswordException;
+use cliNoUserException;
+use cliNotInCWDException;
+use cliUnknownErrorException;
+use cliUserNotAdminException;
+use importException;
+use importFileNotFoundException;
+use importFileNotImportableException;
+use importFileNotInPathException;
+use importIdIsNotNumericException;
+use importMultipleMatchesException;
+use personNotFoundException;
+use placeNotFoundException;
+use userAlreadyExistsException;
 
 /**
  * Controller class for the CLI
@@ -46,7 +65,7 @@ class cli {
      * Defines the API version between the /bin/zoph binary and the files in the webroot
      * these must be equal.
      */
-    const API=6;
+    const API=8;
 
     /**
      * @var user The user that is doing the import
@@ -71,13 +90,13 @@ class cli {
      */
     public function __construct(user $user, $api, array $args) {
         if ($api != static::API) {
-            throw new \cliAPINotCompatibleException("This Zoph installation is not compatible " .
+            throw new cliAPINotCompatibleException("This Zoph installation is not compatible " .
                 "with the Zoph executable you are running.");
         }
         $this->user=$user;
 
         if (!$user->isAdmin()) {
-            throw new \cliUserNotAdminException("CLI_USER must be an admin user");
+            throw new cliUserNotAdminException("CLI_USER must be an admin user");
         }
         user::setCurrent($user);
         $user->prefs->load();
@@ -128,7 +147,7 @@ class cli {
             static::showHelp();
             break;
         default:
-            throw new \cliUnknownErrorException("Unknown command, please file a bug");
+            throw new cliUnknownErrorException("Unknown command, please file a bug");
         }
 
     }
@@ -149,7 +168,7 @@ class cli {
                     if ($file->type=="directory" && conf::get("import.cli.recursive")) {
                         $this->files=array_merge($this->files, file::getFromDir($file, true));
                     } else if ($file->type!="image") {
-                        throw new \importFileNotImportableException("$file is not an image\n");
+                        throw new importFileNotImportableException("$file is not an image\n");
                     } else {
                         $this->files[]=$file;
                     }
@@ -163,19 +182,19 @@ class cli {
                             foreach (range($start, $end) as $id) {
                                 try {
                                     $this->photos[]=$this->lookupFileById($id);
-                                } catch (\importException $e) {
+                                } catch (importException $e) {
                                     echo $e->getMessage();
                                 }
                              }
                         } else {
-                            throw new \importIdIsNotNumericException(
+                            throw new importIdIsNotNumericException(
                                 "$file is not numeric, but --useids is set.\n");
                         }
                     } else {
                         $this->photos[]=$this->lookupFile($filename);
                     }
                 }
-            } catch (\Exception $e) {
+            } catch (Exception $e) {
                 echo $e->getMessage();
             }
         }
@@ -190,9 +209,9 @@ class cli {
         if ($count==1) {
             return $photo;
         } else if ($count==0) {
-            throw new \importFileNotFoundException("No photo with id $id was found\n");
+            throw new importFileNotFoundException("No photo with id $id was found\n");
         } else {
-            throw new \importMultipleMatchesException(
+            throw new importMultipleMatchesException(
                 "Multiple photos with id $id were found. This is probably a bug");
         }
     }
@@ -221,7 +240,7 @@ class cli {
 
             // check if path is in conf::get("path.images")
             if (substr($path, 0, strlen(conf::get("path.images")))!=conf::get("path.images")) {
-                throw new \importFileNotInPathException($path . "/" . $file ." is not in the images path (" .
+                throw new importFileNotInPathException($path . "/" . $file ." is not in the images path (" .
                     conf::get("path.images") . "), skipping.\n");
             } else {
                 $path=substr($path, strlen(conf::get("path.images")));
@@ -240,11 +259,11 @@ class cli {
         }
 
         if (empty($photos)) {
-            throw new \importFileNotFoundException($file ." not found.\n");
+            throw new importFileNotFoundException($file ." not found.\n");
         } else if (sizeof($photos)==1) {
             return $photos[0];
         } else {
-            throw new \importMultipleMatchesException("Multiple files named " . $file ." found.\n");
+            throw new importMultipleMatchesException("Multiple files named " . $file ." found.\n");
         }
     }
 
@@ -287,9 +306,9 @@ class cli {
             } else {
                 $photos=$this->processDirpattern();
             }
-            \import\cli::photos($photos, $vars);
+            cliimport::photos($photos, $vars);
         } else {
-            throw new \cliNoFilesException("Nothing to do, exiting");
+            throw new cliNoFilesException("Nothing to do, exiting");
         }
     }
 
@@ -321,7 +340,7 @@ class cli {
                 }
             }
         } else {
-            throw new \cliNoFilesException("Nothing to do, exiting");
+            throw new cliNoFilesException("Nothing to do, exiting");
         }
     }
     /**
@@ -448,14 +467,18 @@ class cli {
     private function doAddUser() {
         $vars=$this->args->getVars();
         if (!isset($vars["_username"])) {
-            throw new \cliNoUserException(
+            throw new cliNoUserException(
                 sprintf(translate("No user (%s) specified"), "--username"));
         }
         if (!isset($vars["_password"])) {
-            throw new \cliNoPasswordException(
+            throw new cliNoPasswordException(
                 translate("No password specified"));
         }
 
+        if (user::exists($vars["_username"])) {
+            throw new userAlreadyExistsException("Username already exists.");
+        }
+
         $user = new user();
         $user->set("user_name", $vars["_username"]);
         $user->set("password", validator::hashPassword($vars["_password"]));
@@ -476,10 +499,31 @@ class cli {
     private function doDeleteUser() {
         $vars=$this->args->getVars();
         if (!isset($vars["_userid"])) {
-            throw new \cliNoUserException(
+            throw new cliNoUserException(
                 sprintf(translate("No user (%s) specified"), "--username / --userid"));
         }
 
+        $u = new user($vars["_userid"]);
+        $u->lookup();
+        $delete = false;
+        if (!isset($vars["_force"])) {
+            if (posix_isatty(STDIN)) {
+                // Script is run from a terminal
+                echo "Are you sure you want to delete user " . $u->getName() . "? [y/N] ";
+                $response = chop(fgets(STDIN));
+                if (in_array($response, [ "y", "Y" ])) {
+                    $delete = true;
+                }
+            } else {
+                throw new cliException("When deleting a user from a script you must supply -f");
+            }
+        } else {
+            $delete = true;
+        }
+
+        if ($delete) {
+            $u->delete();
+        }
     }
 
     /**
@@ -488,7 +532,7 @@ class cli {
     private function doShowUser() {
         $vars=$this->args->getVars();
         if (!isset($vars["_userid"])) {
-            throw new \cliNoUserException(
+            throw new cliNoUserException(
                 sprintf(translate("No user (%s) specified"), "--username / --userid"));
         }
         $u = new user($vars["_userid"]);
@@ -501,7 +545,7 @@ class cli {
             }, $u->getGroups()
         );
 
-        $tpl = new \template\template("cliShowUser", array(
+        $tpl = new block("cliShowUser", array(
             "userid"   => $u->get("user_id"),
             "username"  => $da["username"],
             "userclass" => $da["class"],
@@ -519,10 +563,55 @@ class cli {
     private function doUpdateUser() {
         $vars=$this->args->getVars();
         if (!isset($vars["_userid"])) {
-            throw new \cliNoUserException(
+            throw new cliNoUserException(
                 sprintf(translate("No user (%s) specified"), "--username / --userid"));
         }
+        $u = new user($vars["_userid"]);
+        $u->lookup();
+        $u = $this->doUpdateAccess($u);
+        $u = $this->doUpdateGroups($u);
+        if (isset($vars["_password"])) {
+            $u->set("password", validator::hashPassword($vars["_password"]));
+        }
+        if (isset($vars["_admin"]) && $vars["_admin"] === true) {
+            $u->set("user_class", 0);
+        }
+        if (isset($vars["_no_admin"]) && $vars["_no_admin"] === true) {
+            $u->set("user_class", 1);
+        }
+        $u->update();
+    }
 
+    private function doUpdateAccess(user $u) {
+        $vars=$this->args->getVars();
+        if (isset($vars["_add_access"]) && is_array($vars["_add_access"])) {
+            foreach ($vars["_add_access"] as $access) {
+                $u->set($access, 1);
+            }
+        }
+        if (isset($vars["_remove_access"]) && is_array($vars["_remove_access"])) {
+            foreach ($vars["_remove_access"] as $access) {
+                $u->set($access, 0);
+            }
+        }
+        return $u;
+    }
+
+    private function doUpdateGroups(user $u) {
+        $vars=$this->args->getVars();
+        if (isset($vars["_groups"]) && is_array($vars["_groups"])) {
+            foreach ($vars["_groups"] as $group) {
+                $g = group::getByName($group);
+                $g->addMember($u);
+            }
+        }
+        if (isset($vars["_remove_groups"]) && is_array($vars["_remove_groups"])) {
+            foreach ($vars["_remove_groups"] as $group) {
+                $g = group::getByName($group);
+                $g->removeMember($u);
+            }
+        }
+        return $u;
     }
 
     /**
@@ -537,7 +626,7 @@ class cli {
         $curlen=strlen($cur);
         foreach ($this->files as $file) {
             if (substr($file, 0, $curlen) != $cur) {
-                throw new \cliNotInCWDException("Sorry, --dirpattern can only be used when " .
+                throw new cliNotInCWDException("Sorry, --dirpattern can only be used when " .
                     "importing files under the current dir. i.e. do not use absolute paths " .
                     "or '../' when specifying --dirpattern.");
             }
@@ -555,46 +644,46 @@ class cli {
                     case "a":
                         // album
                         $album=album::getByName($dir);
-                        if ($album[0] instanceof \album) {
+                        if ($album[0] instanceof album) {
                             if (!is_array($photo->_album_id)) {
                                 $photo->_album_id=array();
                             }
                             $photo->_album_id[]=$album[0]->getId();
                         } else {
-                            throw new \albumNotFoundException("Album not found: " . $dir);
+                            throw new albumNotFoundException("Album not found: " . $dir);
                         }
                         break;
                     case "c":
                         // category
                         $cat=category::getByName($dir);
-                        if ($cat[0] instanceof \category) {
+                        if ($cat[0] instanceof category) {
                             if (!is_array($photo->_category_id)) {
                                 $photo->_category_id=array();
                             }
                             $photo->_category_id[]=$cat[0]->getId();
                         } else {
-                            throw new \categoryNotFoundException("Category not found: " . $dir);
+                            throw new categoryNotFoundException("Category not found: " . $dir);
                         }
                         break;
                     case "l":
                         // location
                         $place=place::getByName($dir);
-                        if ($place[0] instanceof \place) {
+                        if ($place[0] instanceof place) {
                             $photo->set("location_id", $place[0]->getId());
                         } else {
-                            throw new \placeNotFoundException("Place not found: " . $dir);
+                            throw new placeNotFoundException("Place not found: " . $dir);
                         }
                         break;
                     case "p":
                         // person
                         $person=person::getByName($dir);
-                        if ($person[0] instanceof \person) {
+                        if ($person[0] instanceof person) {
                             if (!is_array($photo->_person_id)) {
                                 $photo->_person_id=array();
                             }
                             $photo->_person_id[]=$person[0]->getId();
                         } else {
-                            throw new \personNotFoundException("Person not found: " . $dir);
+                            throw new personNotFoundException("Person not found: " . $dir);
                         }
                         break;
                     case "D":
@@ -608,15 +697,15 @@ class cli {
                     case "P":
                         // photographer
                         $person=person::getByName($dir);
-                        if ($person[0] instanceof \person) {
+                        if ($person[0] instanceof person) {
                             $photo->set("photographer_id", $person[0]->getId());
                         } else {
-                            throw new \personNotFoundException("Person not found: " . $dir);
+                            throw new personNotFoundException("Person not found: " . $dir);
                         }
                         break;
                     default:
                         // should never happen...
-                        throw new \cliUnknownErrorException("Unknown error");
+                        throw new cliUnknownErrorException("Unknown error");
                     }
                 }
                 $counter++;
