@@ -24,8 +24,8 @@
 namespace comment\view;
 
 use conf\conf;
+use template\block;
 use template\form;
-use template\template;
 use web\request;
 use zophCode\smiley;
 
@@ -36,43 +36,11 @@ use user;
 /**
  * This view displays the comment page when editing
  */
-class update {
-    /** @var web\request holds the request */
-    private $request;
-
-    /** @var comment holds the comment */
-    private $comment;
-
-    /** @var photo holds the photo this comment belongs to */
-    private $photo;
-
-    public function __construct(request $request) {
-        $comment=new comment($request["comment_id"]);
-        $comment->lookup();
-        $this->comment=$comment;
-        $this->request=$request;
-        $photo = $comment->getPhoto();
-        if (!$photo instanceof photo && $comment->getId() == 0) {
-            $photo = new photo((int) $request["photo_id"]);
-            $photo->lookup();
-        }
-        $this->photo=$photo;
-    }
-
-    /**
-     * Create the actionlinks for this page
-     */
-    protected function getActionlinks() {
-        return array(
-            "return"    => "photo.php?photo_id=" . $this->photo->getId(),
-            "new"       => "comment.php?_action=new"
-        );
-    }
-
+class update extends view implements \view {
     /**
      * Output the view
      */
-    public function view() {
+    public function view() : block {
         $user = user::getCurrent();
         $photo=$this->photo;
 
@@ -85,11 +53,10 @@ class update {
             $action = $this->request["_action"];
         }
 
-        $tpl = new template("main", array(
+        $tpl = new block("main", array(
             "title"             => $this->getTitle(),
-            "actionlinks"       => $this->getActionlinks(),
-            "mainActionlinks"   => null,
         ));
+        $tpl->addActionlinks($this->getActionlinks());
 
         $tpl->addBlock($photo->getImageTag(MID_PREFIX));
 
@@ -102,10 +69,10 @@ class update {
         ));
 
 
-        $form->addInputHidden("comment_id", $this->comment->getId());
+        $form->addInputHidden("comment_id", $this->object->getId());
         $form->addInputHidden("photo_id", $this->photo->getId());
-        $form->addInputText("subject", $this->comment->get("subject"), translate("subject"));
-        $form->addTextarea("comment", $this->comment->get("comment"), translate("comment"), 80, 8);
+        $form->addInputText("subject", $this->object->get("subject"), translate("subject"));
+        $form->addTextarea("comment", $this->object->get("comment"), translate("comment"), 80, 8);
 
 
         $tpl->addBlock($form);
@@ -120,15 +87,14 @@ class update {
     /**
      * Get the title for this view
      */
-    public function getTitle() {
-        if ($this->comment->getId()==0) {
+    public function getTitle() : string {
+        if ($this->object->getId()==0) {
             return translate("Add comment");
-        } else if (trim($this->comment->get("subject"))=="") {
+        } else if (trim($this->object->get("subject"))=="") {
             return translate("comment");
         } else {
-            return $this->comment->get("subject");
+            return $this->object->get("subject");
         }
     }
 
-
 }
