@@ -159,7 +159,9 @@ class conf {
      * @return string Value of parameter
      */
     public static function get($key) {
-        if (!static::$loaded) {
+        if (defined("INSTALL")) {
+            minimal::getConfig();
+        } else if (!static::$loaded) {
             static::loadFromDB();
         }
         $item=static::getItemByName($key);
