@@ -74,7 +74,7 @@ class confDefault extends conf {
         $zophVersion->setLabel("Zoph Version");
         $zophVersion->setDesc("The current version of Zoph. You should not need to change this. " .
             "Changing this may lead to unexpected behaviour.");
-        $zophVersion->setDefault("v00.09.19.000");
+        $zophVersion->setDefault("v00.09.24.000");
         $zophVersion->setRegex("^v([[0-9]{2}\.){3}[0-9]{3}");
         $zophVersion->setInternal();
         $zoph[]=$zophVersion;
@@ -299,7 +299,7 @@ class confDefault extends conf {
             "/usr/share/misc/magic.mgc, /usr/share/misc/file/magic.mgc, " .
             "/usr/share/file/magic are often used.");
         $pathMagic->setDefault("");
-        $pathMagic->setRegex("^\/[A-Za-z0-9_.\/]+$");
+        $pathMagic->setRegex("^(\/[A-Za-z0-9_.\/]+)?$");
         $pathMagic->setHint("Alphanumeric characters (A-Z, a-z and 0-9), forward " .
             "slash (/), dot (.), and underscore (_). Must start with a /. Can be " .
             "empty for PHP builtin magic file.");
@@ -817,6 +817,14 @@ class confDefault extends conf {
         $featureComments->setDefault(false);
         $feature[]=$featureComments;
 
+        $featureSets = new checkbox();
+        $featureSets->setName("feature.sets");
+        $featureSets->setLabel("Photo sets");
+        $featureSets->setDesc("Enable the posibility to group photos in a set " .
+            "in a set, the order of the photos can be modified.");
+        $featureSets->setDefault(false);
+        $feature[]=$featureSets;
+
         $featureMail = new checkbox();
         $featureMail->setName("feature.mail");
         $featureMail->setLabel("Mail photos");
