@@ -143,6 +143,14 @@ abstract class item extends zophTable {
         }
     }
 
+    /**
+     * Get value of item for display
+     * @return string value
+     */
+    public function displayValue() {
+        return $this->getValue();
+    }
+
     /**
      * Set value of item
      * @param string value
