@@ -116,6 +116,7 @@ abstract class query {
         foreach ($functions as $alias => $function) {
             $this->fields[]=$function . " AS " . $alias;
         }
+        return $this;
     }
 
     /**
@@ -189,7 +190,7 @@ abstract class query {
             } else if (strtoupper($conj) == "OR") {
                 $this->where->addOr($clause);
             } else {
-                throw new \databaseException("Unknown conjunction: " . e($conj));
+                throw new exception("Unknown conjunction: " . e($conj));
             }
         } else {
             $this->where($clause);
