@@ -73,7 +73,7 @@ class select extends query {
      */
     public function join(array $table, $on, $jointype="INNER") {
         if (!in_array($jointype, array("INNER", "LEFT", "RIGHT"))) {
-            throw new \databaseException("Unknown JOIN type");
+            throw new exception("Unknown JOIN type");
         }
 
         $tbl=reset($table);
@@ -223,7 +223,7 @@ class select extends query {
         try {
             $result = db::query($this);
         } catch (\PDOException $e) {
-            log::msg("Unable to get count", log::FATAL, log::DB);
+            throw new exception("Unable to get count");
         }
 
         return $result->fetch(PDO::FETCH_BOTH)[0];
