@@ -26,9 +26,8 @@
 namespace generic;
 
 use breadcrumb;
-
+use exception;
 use web\request;
-
 use zophTable;
 
 /**
@@ -37,6 +36,13 @@ use zophTable;
  */
 abstract class controller {
 
+    protected static $viewConfirm   = view\confirm::class;
+    protected static $viewDisplay   = view\display::class;
+    protected static $viewNew       = view\update::class;
+    protected static $viewRedirect  = \web\view\redirect::class;
+    protected static $viewUpdate    = view\update::class;
+    protected static $viewForbidden = view\forbidden::class;
+
     /** @var request holds request */
     protected   $request;
     /** @var zophTable holds object to operate on */
@@ -46,7 +52,7 @@ abstract class controller {
     /** @var array Actions that can be used in this controller */
     protected   $actions    = array("confirm", "delete", "display", "edit", "insert", "new", "update");
     /** @var string view to call after action */
-    protected   $view       = "display";
+    protected   $view       = null;
 
     /**
      * Create a new controller from a web request
@@ -85,6 +91,9 @@ abstract class controller {
         } else {
             $this->actionDisplay();
         }
+        if ($this->view?->getTitle() && !defined("TEST")) {
+            breadcrumb::create($this->view->getTitle(), $action);
+        }
     }
 
     /**
@@ -93,10 +102,20 @@ abstract class controller {
      * current object.
      */
     protected function actionEdit() {
-        $this->view = "update";
+        $this->view = new static::$viewUpdate($this->request, $this->object);
 
     }
 
+    /**
+     * Action: forbidden
+     * This action can be called when a user does something that he is not allowed to do
+     * this should only happen if a user is, for example, altering the URL manually
+     * because in normal program flow no links to "forbidden" parts should be shown
+     */
+    protected function actionForbidden(exception $e) {
+        $this->view = new static::$viewForbidden($this->request, $e);
+    }
+
     /**
      * Action: update
      * The update action processes a form as generated after the "edit" action.
@@ -105,7 +124,7 @@ abstract class controller {
     protected function actionUpdate() {
         $this->object->setFields($this->request->getRequestVars());
         $this->object->update();
-        $this->view = "display";
+        $this->view = new static::$viewUpdate($this->request, $this->object);
 
     }
 
@@ -116,7 +135,7 @@ abstract class controller {
      */
     protected function actionNew() {
         $this->object->setFields($this->request->getRequestVars());
-        $this->view = "insert";
+        $this->view = new static::$viewNew($this->request, $this->object);
     }
 
     /**
@@ -127,7 +146,7 @@ abstract class controller {
     protected function actionInsert() {
         $this->object->setFields($this->request->getRequestVars());
         $this->object->insert();
-        $this->view = "display";
+        $this->view = new static::$viewDisplay($this->request, $this->object);
 
     }
 
@@ -136,7 +155,7 @@ abstract class controller {
      * The delete action asks for confirmation of a delete of the current object
      */
     protected function actionDelete() {
-        $this->view = "confirm";
+        $this->view = new static::$viewConfirm($this->request, $this->object);
 
     }
 
@@ -156,22 +175,18 @@ abstract class controller {
             $this->redirect=urldecode(html_entity_decode($crumb->getURL()));
         }
 
-        $this->view = "redirect";
+        $this->view = new static::$viewRedirect($this->request);
     }
 
     /**
      * The display action displays the object
      */
     protected function actionDisplay() {
-        $this->view = "display";
+        $this->view = new static::$viewDisplay($this->request, $this->object);
     }
 
     /**
      * get View
-     * each of the actions dictate a subsequent view in the workflow,
-     * the view can be called by this function
-     * currently, it simply returns a name, in the future an action View object
-     * may be returned.
      */
     public function getView() {
         return $this->view;
