@@ -219,11 +219,11 @@ class group extends zophTable {
     }
 
     /**
-     * Create a pulldown to add new members to this group
-     * @param string name for the pulldown field
-     * @return template Pulldown
+     * Create a dropdown to add new members to this group
+     * @param string name for the dropdown field
+     * @return template Dropdown
      */
-    public function getNewMemberPulldown($name) {
+    public function getNewMemberDropdown($name) {
         $valueArray=array();
 
         $newMembers=$this->getNonMembers();
@@ -232,7 +232,7 @@ class group extends zophTable {
             $nm->lookup();
             $valueArray[$nm->getId()]=$nm->getName();
         }
-        return template::createPulldown($name, null, $valueArray);
+        return template::createDropdown($name, null, $valueArray);
     }
 
     /**
@@ -250,6 +250,24 @@ class group extends zophTable {
         }
         return $links;
     }
+
+    public static function getByName(string $name) {
+        $groups = static::getRecords(null, array("group_name" => $name));
+        if (empty($groups)) {
+            throw new groupNotFoundException("Group not found");
+        } else {
+            return $groups[0];
+        }
+    }
+
+    public static function exists(string $name) {
+        try {
+            self::getByName($name);
+        } catch (groupNotFoundException $e) {
+            return false;
+        }
+        return true;
+    }
 }
 
 ?>
