@@ -28,29 +28,27 @@ use group;
 use permissions\view\edit as editPermissions;
 use template\block;
 use template\form;
-use template\template;
 use web\request;
 
 /**
  * Update screen for group
  */
-class update extends view {
+class update extends view implements \view {
 
     /**
      * Get actionlinks
      * @return array actionlinks
      */
-    protected function getActionlinks() {
+    protected function getActionlinks() : array {
         if ($this->request["_action"] == "new") {
             return array(
-                translate("delete")    => "group.php?_action=delete&amp;group_id=" . $this->group->getId(),
-                translate("return")    => "groups.php"
+                translate("return")    => "group.php?_action=groups"
             );
         } else {
             return array(
-                translate("delete")    => "group.php?_action=delete&amp;group_id=" . $this->group->getId(),
+                translate("delete")    => "group.php?_action=delete&amp;group_id=" . $this->object->getId(),
                 translate("new")       => "group.php?_action=new",
-                translate("return")    => "group.php?group_id=" . $this->group->getId()
+                translate("return")    => "group.php?group_id=" . $this->object->getId()
             );
         }
     }
@@ -58,18 +56,17 @@ class update extends view {
 
     /**
      * Get view
-     * @return template view
+     * @return block view
      */
-    public function view() {
+    public function view() : block {
         $_action = $this->request["_action"];
 
-        $tpl=new template("edit", array(
+        $tpl=new block("main", array(
             "title"             => $this->getTitle(),
-            "actionlinks"       => $this->getActionlinks(),
-            "mainActionlinks"   => null,
-            "obj"               => $this->group,
         ));
 
+        $tpl->addActionlinks($this->getActionlinks());
+
         $form=new form("form", array(
             "formAction"        => "group.php",
             "onsubmit"          => null,
@@ -77,25 +74,26 @@ class update extends view {
             "submit"            => translate("submit")
         ));
 
-        $form->addInputHidden("group_id", $this->group->getId());
+        $form->addInputHidden("group_id", $this->object->getId());
 
-        $form->addInputText("group_name", $this->group->getName(), translate("group name"),
+        $form->addInputText("group_name", $this->object->getName(), translate("group name"),
             sprintf(translate("%s chars max"), 32), 32);
 
-        $form->addInputText("description", $this->group->get("description"),
+        $form->addInputText("description", $this->object->get("description"),
             translate("description"), sprintf(translate("%s chars max"), 128), 128, 32);
 
         if ($_action != "new") {
-            $curMembers=$this->group->getMembers();
-            $members=new block("members", array(
-                "members"   => $curMembers,
-                "group"     => $this->group
+            $curMembers=$this->object->getMembers();
+            $members=new block("formFieldsetAddRemove", array(
+                "legend"    => translate("members"),
+                "objects"   => $curMembers,
+                "dropdown"  => $this->object->getNewMemberDropdown("_member")
             ));
             $form->addBlock($members);
 
             $tpl->addBlock($form);
 
-            $view=new editPermissions($this->group);
+            $view=new editPermissions($this->object);
             $tpl->addBlock($view->view());
 
         } else {
@@ -109,7 +107,7 @@ class update extends view {
         return $tpl;
     }
 
-    public function getTitle() {
+    public function getTitle() : string {
         if ($this->request["_action"] == "new") {
             return translate("New group");
         } else {
