@@ -23,56 +23,34 @@
 
 namespace group\view;
 
+use group;
 use template\template;
 use web\request;
-use group;
+use web\view\view as webView;
 
 /**
  * Holds the common parts for the group views
  */
-abstract class view {
-    /** @var request hold the request for this view */
-    protected $request;
-    /** @var group the group that is going to be deleted */
-    protected $group;
-
+abstract class view extends webView implements \view {
     /**
      * Create view
      * @param request web request
-     * @param group group
      */
-    public function __construct(request $request, group $group) {
-        $this->request = $request;
-        $this->group = $group;
-    }
-
-    /**
-     * Get headers - null, so default headers will be used
-     * @return null
-     */
-    public function getHeaders() {
-        return null;
+    public function __construct(protected request $request, protected ?group $object = null) {
     }
 
     /**
      * Get title
      * @return string title
      */
-    public function getTitle() {
-        return $this->group->getName();
+    public function getTitle() : string {
+        return $this->object->getName();
     }
 
     /**
      * Get actionlinks
      * @return array actionlinks
      */
-    abstract protected function getActionlinks();
-
-    /**
-     * Output view
-     * @return template
-     */
-    abstract public function view();
-
+    abstract protected function getActionlinks() : ?array;
 
 }
