@@ -23,6 +23,7 @@ namespace import;
 use file;
 use log;
 use photo;
+use photo\exif;
 use category;
 use settings;
 
@@ -93,7 +94,7 @@ abstract class base {
 
             $mime=$file->getMime();
             if (conf::get("import.cli.exif")===true && $mime=="image/jpeg") {
-                $exif=process_exif($file);
+                $exif=exif::process($file);
                 if ($exif) {
                     $photo->setFields($exif);
                 }
