@@ -288,7 +288,7 @@ class language {
 
     public static function getCurrentISO() {
         global $lang;
-        return $lang->iso;
+        return $lang->iso ?? "en";
     }
 }
 
