@@ -86,6 +86,10 @@ class page extends zophTable {
         parent::delete(array("pages_pageset"));
     }
 
+    public function getName() {
+        return $this->get("title");
+    }
+
     /**
      * Return an array of fields to display
      * @todo Returns HTML
