@@ -101,7 +101,7 @@ class pageset extends zophTable {
      * be displayed
      */
     public function getOriginalDropdown() {
-        return template::createPulldown("show_orig", $this->get("show_orig"),
+        return template::createDropdown("show_orig", $this->get("show_orig"),
             array(
                 "never" => translate("Never", 0),
                 "first" => translate("On first page", 0),
@@ -138,6 +138,10 @@ class pageset extends zophTable {
         return $qry->getCount();
     }
 
+    public function getName() {
+        return $this->get("title");
+    }
+
     /**
      * Add a page to this set
      * @param page Page to add
