@@ -23,6 +23,7 @@
  * @package Zoph
  */
 
+use conf\conf;
 use db\select;
 use db\param;
 use db\insert;
@@ -31,10 +32,10 @@ use db\delete;
 use db\db;
 use db\clause;
 use db\selectHelper;
-
-use conf\conf;
-
 use photo\collection;
+use template\template;
+
+
 
 
 /**
@@ -44,7 +45,7 @@ use photo\collection;
  * @author Jeroen Roos
  * @package Zoph
  */
-class person extends zophTable implements Organizer {
+class person extends zophTable implements organizer {
 
     use showPage;
 
@@ -111,17 +112,22 @@ class person extends zophTable implements Organizer {
      * @param photo Photo to add the person to
      */
     public function addPhoto(photo $photo, $row = 0) {
-        $pos = (new photo\people($photo))->getLastPos($row);
-        $pos++;
+        if (!(new photo\people($photo))->getPosition($this)) {
+            $pos = (new photo\people($photo))->getLastPos($row);
+            $pos++;
 
-        $qry=new insert(array("photo_people"));
-        $qry->addParams(array(
-            new param(":photo_id", (int) $photo->getId(), PDO::PARAM_INT),
-            new param(":person_id", (int) $this->getId() , PDO::PARAM_INT),
-            new param(":position", (int) $pos, PDO::PARAM_INT),
-            new param(":row", (int) $row, PDO::PARAM_INT)
-        ));
-        $qry->execute();
+            $qry=new insert(array("photo_people"));
+            $qry->addParams(array(
+                new param(":photo_id", (int) $photo->getId(), PDO::PARAM_INT),
+                new param(":person_id", (int) $this->getId() , PDO::PARAM_INT),
+                new param(":position", (int) $pos, PDO::PARAM_INT),
+                new param(":row", (int) $row, PDO::PARAM_INT)
+            ));
+            $qry->execute();
+        } else {
+            // person is already in this photo
+            return false;
+        }
     }
 
     /**
@@ -129,23 +135,15 @@ class person extends zophTable implements Organizer {
      * @param photo photo to remove the person from
      */
     public function removePhoto(photo $photo) {
-        // First, get the position for the person who is about to be removed
-        $qry=new select(array("photo_people"));
+        list($row, $pos) = (new photo\people($photo))->getPosition($this);
+
         $where=new clause("photo_id=:photo_id");
         $where->addAnd(new clause("person_id=:person_id"));
-
-        $params=array(
+        $params = array(
             new param(":photo_id", (int) $photo->getId(), PDO::PARAM_INT),
             new param(":person_id", (int) $this->getId(), PDO::PARAM_INT)
         );
 
-        $qry->where($where);
-        $qry->addParams($params);
-
-        $result=db::query($qry)->fetch(PDO::FETCH_ASSOC);
-        $row=$result["row"];
-        $pos=$result["position"];
-
         $qry=new delete("photo_people");
         $qry->where($where);
         $qry->addParams($params);
@@ -155,7 +153,7 @@ class person extends zophTable implements Organizer {
 
         $where=new clause("photo_id=:photo_id");
         $where->addAnd(new clause("position>:pos"));
-        $where->addAnd(new clause("row=:row"));
+        $where->addAnd(new clause("`row`=:row"));
 
         $qry->addSetFunction("position=position-1");
 
@@ -260,7 +258,7 @@ class person extends zophTable implements Organizer {
      * @return person father
      */
     private function getFather() {
-        return static::getFromId($this->get("father_id"));
+        return static::getFromId((int) $this->get("father_id"));
     }
 
     /**
@@ -268,7 +266,7 @@ class person extends zophTable implements Organizer {
      * @return person mother
      */
     private function getMother() {
-        return static::getFromId($this->get("mother_id"));
+        return static::getFromId((int) $this->get("mother_id"));
     }
 
     /**
@@ -276,7 +274,7 @@ class person extends zophTable implements Organizer {
      * @return person spouse
      */
     private function getSpouse() {
-        return static::getFromId($this->get("spouse_id"));
+        return static::getFromId((int) $this->get("spouse_id"));
     }
 
     /**
@@ -374,7 +372,6 @@ class person extends zophTable implements Organizer {
         $mother=$this->getMother();
         $father=$this->getFather();
         $spouse=$this->getSpouse();
-
         $dob = new Time($this->get("dob"));
         $dod = new Time($this->get("dod"));
 
@@ -519,7 +516,7 @@ class person extends zophTable implements Organizer {
         if ($result) {
             return $result->fetch(PDO::FETCH_ASSOC);
         } else {
-            return null;
+            return array();
         }
     }
 
@@ -527,8 +524,8 @@ class person extends zophTable implements Organizer {
      * Turn the array from @see getDetails() into XML
      * @param array Don't fetch details, but use the given array
      */
-    public function getDetailsXML(array $details=null) {
-        if (!isset($details)) {
+    public function getDetailsXML(array $details = array()) {
+        if (empty($details)) {
             $details=$this->getDetails();
         }
         $details["title"]=translate("Photos taken by this person:", false);
@@ -545,9 +542,45 @@ class person extends zophTable implements Organizer {
         $qry->where(new clause("person_id=:personid"));
         $qry->addParam(new param(":personid", (int) $this->getId(), PDO::PARAM_INT));
 
+        return array_map(function($c) { $c->lookup(); return $c; }, circle::getRecordsFromQuery($qry));
+    }
+
+    /**
+     * Get array of circles this person is NOT a member of
+     * @return array of circles
+     */
+    public function getNoCircles() {
+        $qry=new select(array("c" => "circles"));
+
+        $circles = $this->getCircles();
+        if (!empty($circles)) {
+            $circleIds=array_map(function($p) { return $p->getId(); }, $circles);
+            $param=new param(":circleIds", (array) $circleIds, PDO::PARAM_INT);
+            $qry->where(clause::NotInClause("c.circle_id", $param));
+            $qry->addParam($param);
+        }
         return circle::getRecordsFromQuery($qry);
     }
 
+    /**
+     * Create a dropdown to add this person to a circle
+     * @param string name for the dropdown field
+     * @return template Dropdown
+     */
+    public function getCircleDropdown(string $name) {
+        $valueArray=array();
+
+        $circles=$this->getNoCircles();
+        $valueArray[0]=null;
+        foreach ($circles as $c) {
+            $c->lookup();
+            $valueArray[$c->getId()]=$c->getName();
+        }
+        return template::createDropdown($name, null, $valueArray);
+    }
+
+
+
     /**
      * Return whether the currently logged on user can see this person
      * @param user Use this user instead of the logged in one
@@ -579,6 +612,10 @@ class person extends zophTable implements Organizer {
         return ($user->getId()===$this->get("createdby"));
     }
 
+    public function isWritableBy(user $user) {
+        return $user->canEditOrganizers();
+    }
+
     /**
      * Lookup person by name;
      * @param string name
@@ -775,13 +812,15 @@ class person extends zophTable implements Organizer {
             }
             $allowed=array_unique($allowed);
             if (count($allowed)==0) {
-                return null;
+                return array();
             }
             $param=new param(":person_ids", $allowed, PDO::PARAM_INT);
             $qry->where(clause::InClause("person_id", $param));
             $qry->addParam($param);
         } else if ($search!==null) {
-            $qry->addParam(new param("search", $search, PDO::PARAM_STR));
+            if(trim($search) != "") {
+                $qry->addParam(new param("search", $search, PDO::PARAM_STR));
+            }
             $qry->where(static::getWhereForSearch($search));
         }
         $all=static::getRecordsFromQuery($qry);
@@ -839,7 +878,7 @@ class person extends zophTable implements Organizer {
     public static function getWhereForSearch($search, $search_first=false, $paramname="search") {
         $where=null;
         if ($search!==null) {
-            if ($search==="") {
+            if (trim($search)==="") {
                 $where=new clause("ppl.last_name=''");
                 $where->addOr(new clause("ppl.last_name is null"));
             } else {
