@@ -23,7 +23,7 @@
 
 namespace person\view;
 
-use template\template;
+use template\block;
 use web\request;
 use person;
 use photo;
@@ -32,49 +32,34 @@ use user;
 /**
  * This view displays the "confirm person" page
  */
-class confirm {
+class confirm extends view implements \view {
 
-    /** * @var array request variables */
-    private $vars;
-    /** * @var request web request */
-    private $request;
-    /** * @var person */
-    private $person;
-
-    /**
-     * Create view
-     * @param request web request
-     * @param person person to operate on
-     */
-    public function __construct(request $request, person $person) {
-        $this->request=$request;
-        $this->vars=$request->getRequestVars();
-        $this->person=$person;
+    protected function getActionlinks() : array {
+        return array(
+            translate("confirm")   =>  "person.php?_action=confirm&amp;person_id=" . $this->object->getId(),
+            translate("cancel")    =>  "person.php?person_id=" . $this->object->getId()
+        );
     }
 
     /**
      * Output view
      */
-    public function view() {
-        $cover = $this->person->getCoverphoto();
+    public function view() : block {
+        $cover = $this->object->getCoverphoto();
         if ($cover instanceof photo) {
             $cover = $cover->getImageTag(THUMB_PREFIX);
         }
-        $actionlinks=array(
-            translate("confirm")   =>  "person.php?_action=confirm&amp;person_id=" . $this->person->getId(),
-            translate("cancel")    =>  "person.php?person_id=" . $this->person->getId()
-        );
-        return new template("confirm", array(
+        return new block("confirm", array(
             "title"         => $this->getTitle(),
-            "actionlinks"   => $actionlinks,
+            "actionlinks"   => $this->getActionlinks(),
             "mainActionlinks" => null,
-            "obj"           => $this->person,
+            "obj"           => $this->object,
             "image"         => $cover
         ));
 
     }
 
-    public function getTitle() {
-        return sprintf(translate("Confirm deletion of '%s'"), $this->person->getName());
+    public function getTitle() : string {
+        return sprintf(translate("Confirm deletion of '%s'"), $this->object->getName());
     }
 }
