@@ -1,6 +1,6 @@
 <?php
 /**
- * View for edit photo page // WIP
+ * View for edit photo page
  *
  * This file is part of Zoph.
  *
@@ -25,7 +25,7 @@ namespace person\view;
 
 use conf\conf;
 use geo\map;
-use template\template;
+use template\block;
 use web\request;
 
 use album;
@@ -38,13 +38,13 @@ use user;
 /**
  * This view displays the person page when editing
  */
-class update extends common {
+class update extends view {
     /**
      * Create the actionlinks for this page
      */
-    protected function getActionlinks() {
+    protected function getActionlinks() : ?array {
         $actionlinks = array();
-        $actionlinks[translate("return")] = "people.php";
+        $actionlinks[translate("return")] = "person.php?_action=people";
         if ($this->request["_action"] != "new") {
             $actionlinks[translate("new")] = "person.php?_action=new";
         }
@@ -54,7 +54,7 @@ class update extends common {
     /**
      * Output the view
      */
-    public function view() {
+    public function view() : block {
         $user = user::getCurrent();
 
         if ($this->request["_action"] == "new") {
@@ -66,11 +66,18 @@ class update extends common {
             $action = $this->request["_action"];
         }
 
-        $tpl = new template("editPerson", array(
+        $circles = new block("formFieldsetAddRemove", array(
+            "legend"    => translate("circles"),
+            "objects"   => $this->object->getCircles(),
+            "dropdown"  => $this->object->getCircleDropdown("_circle")
+        ));
+
+        $tpl = new block("editPerson", array(
             "actionlinks"   => $this->getActionlinks(),
             "action"    => $action,
-            "person"    => $this->person,
-            "title"     => $this->getTitle()
+            "person"    => $this->object,
+            "title"     => $this->getTitle(),
+            "circles"   => $circles
         ));
         return $tpl;
     }
