@@ -36,6 +36,10 @@ use geo\point;
 use geo\track;
 use geo\marker;
 
+use photo\exif;
+use photo\relation\model as photoRelation;
+use set\model as set;
+
 use template\block;
 use template\template;
 
@@ -110,8 +114,13 @@ class photo extends zophTable {
               $header["http_status"]="HTTP/1.1 304 Not Modified";
               $jpeg=null;
         } else {
-            $file=new file($image_path);
-            $image_type=$file->getMime();
+            try {
+                $file=new file($image_path);
+                $image_type=$file->getMime();
+            } catch (Exception $e) {
+                throw new photoNotFoundException($name . " could not be found: " . $e->getMessage());
+            }
+
             if ($image_type) {
                 $header["Content-Length"] = $filesize;
                 $header["Content-Disposition"]="inline; filename=" . $name;
@@ -217,8 +226,11 @@ class photo extends zophTable {
             "photo_categories",
             "photo_albums",
             "photo_ratings",
-            "photo_comments")
+            "photo_comments",
+            "photo_sets")
         );
+
+        set::renumberAll();
     }
 
     /**
@@ -249,8 +261,10 @@ class photo extends zophTable {
     public function updateRelations(array $vars, $suffix = "") {
 
         $albums=album::getFromVars($vars, $suffix);
+
         $categories=category::getFromVars($vars, $suffix);
         $people=person::getFromVars($vars, $suffix);
+        $sets=set::getFromVars($vars, $suffix);
 
         // Albums
         if (!empty($vars["_remove_album$suffix"])) {
@@ -302,6 +316,18 @@ class photo extends zophTable {
         if (isset($this->_rate)) {
             $this->rate($this->_rate);
         }
+
+        // Sets
+        if (isset($this->_set_id)) {
+            $sets=array_merge($sets, $this->_set_id);
+            unset($this->_set_id);
+        }
+
+        foreach ($sets as $setId) {
+            $set = new set($setId);
+            $set->addPhoto($this);
+        }
+
     }
 
     /**
@@ -340,7 +366,7 @@ class photo extends zophTable {
      */
     public function updateEXIF() {
         $file=$this->getFilePath();
-        $exif=process_exif($file);
+        $exif=exif::process($file);
         if ($exif) {
             $this->setFields($exif);
             $this->update();
@@ -611,6 +637,7 @@ class photo extends zophTable {
 
         return new block("img", array(
             "src"   => $image_href,
+            "data_photo_id" => $this->getId(),
             "class" => $type,
             "size"  => $size,
             "alt"   => $alt
@@ -1148,7 +1175,7 @@ class photo extends zophTable {
                     if (!is_array($value)) {
                         $return .="    <dt>$key</dt>\n" .
                                   "    <dd>" .
-                                          preg_replace("/[^[:print:]]/", "", $value) .
+                                          preg_replace("/[^[:print:]]/", "", $value ?? "") .
                                   "    </dd>\n";
                     } else {
                         $return .="    <dt>$key</dt>\n" .
@@ -1156,8 +1183,8 @@ class photo extends zophTable {
                                   "        <dl>\n";
                         foreach ($value as $subkey => $subval) {
                             $return .= "     <dt>$subkey</dt>\n" .
-                                       "     <dd>" .
-                                               preg_replace("/[^[:print:]]/", "", $subval) .
+                    "     <dd>" .
+                                               preg_replace("/[^[:print:]]/", "", $subval ?? "") .
                                        "     </dd>\n";
                         }
                         $return .= "         </dl>\n" .
@@ -1586,7 +1613,7 @@ class photo extends zophTable {
         $bytes=0;
         foreach ($photos as $photo) {
             $photo->lookup();
-            $bytes+=$photo->get("size");
+            $bytes+=(int) $photo->get("size");
         }
 
         return $bytes;
