@@ -23,30 +23,29 @@
 
 namespace photo\view;
 
+use calendar\model as calendar;
 use conf\conf;
 use geo\map;
-use photo\people as photoPeople;
-use template\block;
-use template\template;
-use web\request;
-
-use calendar;
 use photo;
+use photo\people as photoPeople;
 use rating;
 use selection;
+use template\block;
+use template\template;
 use Time;
 use user;
+use web\request;
 
 /**
  * This view displays the "photo" page
  */
-class display extends common {
+class display extends view {
 
     /**
      * Get comments for the current photo
      * @return block template block
      */
-    private function getComments() {
+    private function getComments() : ?block {
         if (conf::get("feature.comments")) {
             $comments=$this->photo->getComments();
             if ($comments) {
@@ -54,15 +53,15 @@ class display extends common {
                     "comments"  => $comments
                 ));
             }
-            return isset($commentTpl) ? $commentTpl : null;
         }
+        return $commentTpl ?? null;
     }
 
     /**
      * Get related photos for the current photo
      * @return block template block
      */
-    private function getRelated() {
+    private function getRelated() : ?block {
         $related=$this->photo->getRelated();
         if ($related) {
             $tplRelated=new block("related_photos", array(
@@ -78,7 +77,7 @@ class display extends common {
      * Get EXIF information for current photo
      * @return block template block
      */
-    private function getExif() {
+    private function getExif() : ?block {
         if (user::getCurrent()->prefs->get("allexif")) {
             $exif=new block("exif", array(
                 "allexif"   => $this->photo->exifToHTML()
@@ -91,7 +90,7 @@ class display extends common {
      * Get rating block (display) for current photo
      * @return block template block
      */
-    private function getRating() {
+    private function getRating() : null|block|float {
         $rating = $this->photo->getRating();
         if ($rating && user::getCurrent()->isAdmin()) {
             $rating=$this->photo->getRatingDetails();
@@ -103,11 +102,11 @@ class display extends common {
      * Get rating block (to rate) for current photo
      * @return block template block
      */
-    private function getRatingForm() {
+    private function getRatingForm() : ?block {
         $user = user::getCurrent();
         if (conf::get("feature.rating") && $user->canRatePhotos()) {
             $ratingForm=new block("formRating", array(
-                "ratingPulldown"=> rating::createPulldown("rating", $this->photo->getRatingForUser($user)),
+                "ratingDropdown"=> rating::createDropdown("rating", $this->photo->getRatingForUser($user)),
                 "photoId"       => $this->photo->getId()
             ));
         }
@@ -118,7 +117,7 @@ class display extends common {
      * Get action links
      * @return array action links
      */
-    protected function getActionlinks() {
+    protected function getActionlinks() : array {
         $actionlinks=parent::getActionlinks();
         unset($actionlinks[translate("cancel")]);
         unset($actionlinks[translate("return")]);
@@ -129,7 +128,7 @@ class display extends common {
     /**
      * Output view
      */
-    public function view() {
+    public function view() : block {
         $user = user::getCurrent();
         $photo = $this->photo;
         $photo->lookup();
@@ -138,6 +137,8 @@ class display extends common {
             $permissions = $user->getPhotoPermissions($photo);
         }
 
+        $this->setLinks();
+
         $camInfo = $user->prefs->get("camera_info") ? $photo->getCameraDisplayArray() : null;
 
         $calendar = new calendar();
@@ -149,19 +150,29 @@ class display extends common {
 
         $timestamp = new Time($photo->get("timestamp"));
 
-        $tpl = new template("displayPhoto", array(
-            "photo"         => $photo,
-            "actionlinks"   => $this->getActionlinks(),
-            "title"         => $this->getTitle($this->photocount, $this->offset),
-            "selection"     => $this->getSelection(),
+        if (conf::get("maps.provider")) {
+            $map = new map();
+            $photos=$photo->getNear(100);
+            $photos[]=$photo;
+            $map->addMarkers($photos, $user);
+        }
+        $prevnext = new block("photoPrevNext", array(
             "prev"          => $this->prevURL,
             "up"            => $this->upURL,
-            "next"          => $this->nextURL,
+            "next"          => $this->nextURL
+        ));
+
+        return new block("displayPhoto", array(
+            "photo"         => $photo,
+            "actionlinks"   => $this->getActionlinks(),
+            "title"         => $this->getTitle(),
+            "selection"     => $this->getSelection(),
+            "prevnext"      => $prevnext,
             "full"          => $full=$photo->getFullsizeLink($photo->get("name")),
             "size"          => template::getHumanReadableBytes((int)$photo->get("size")),
             "share"         => $this->getShare(),
             "image"         => $photo->getFullsizeLink($photo->getImageTag(MID_PREFIX)),
-            "people"        => isset($people) ? $people : null,
+            "people"        => $people ?? null,
             "fields"        => $photo->getDisplayArray(),
             "rating"        => $this->getRating(),
             "ratingForm"    => $this->getRatingForm(),
@@ -173,18 +184,8 @@ class display extends common {
             "camInfo"       => $camInfo,
             "related"       => $this->getRelated(),
             "exifdetails"   => $this->getExif(),
-            "comments"      => $this->getComments()
+            "comments"      => $this->getComments(),
+            "map"           => $map ?? null
         ));
-
-        if (conf::get("maps.provider")) {
-            $map = new map();
-            $photos=$photo->getNear(100);
-            $photos[]=$photo;
-            $map->addMarkers($photos, $user);
-            $tpl .= $map;
-        }
-
-        return $tpl;
-
     }
 }
