@@ -24,26 +24,17 @@
 namespace photo\view;
 
 use web\request;
-use template\template;
+use template\block;
 
 /**
  * This view displays a "not found" error in case no photo was found
  */
-class notfound {
-    /**
-     * Create view
-     * @param request web request
-     */
-    public function __construct(request $request) {
-        $this->request=$request;
-        $this->vars=$request->getRequestVars();
-    }
-
+class notfound extends view {
     /**
      * Output view
      */
-    public function view() {
-        return new template("notFound", array(
+    public function view() : block {
+        return new block("notFound", array(
             "title" => translate("Photo"),
             "msg"   => translate("No photo was found")
         ));
