@@ -38,7 +38,7 @@ use photo\collection;
  * @author Jeroen Roos
  * @package Zoph
  */
-class photographer extends person implements Organizer {
+class photographer extends person implements organizer {
 
     /**
      * Add this person to a photo.
