@@ -172,10 +172,10 @@ class params {
     */
     public function getStyle() {
         if (!($this->displayCount == 0 || $this->cols <= 4)) {
-            $width = ((THUMB_SIZE + 14) * $this->cols) + 25;
+            $width = ((THUMB_SIZE + 50) * $this->cols) + 25;
             $defaultWidth= conf::get("interface.width");
             if ($width > $defaultWidth || strpos($defaultWidth, "%")) {
-                return "body    { width: " . $width . "px; }\n";
+                return "body    { min-width: " . $width . "px; }\n";
             }
         }
     }
