@@ -38,20 +38,10 @@ use user;
  * This view displays the "photos" page
  */
 class display extends view {
-
-    /** @var photo\collection photos for this request */
-    private $photos;
-
-    /** @var photo\collection photos to display */
-    private $display;
-
-    /** @var array of photo_ids that are in this user's lightbox */
-    private $lightbox;
-
     /**
      * Output view
      */
-    public function view() {
+    public function view() : block {
 
         switch($this->params->dir) {
         case "asc":
@@ -71,10 +61,14 @@ class display extends view {
 
         $viewformvars = $this->request->getUpdatedVars(null, null,
             array ("_rows", "_cols", "_order", "_button"));
-        $order=template::createPhotoFieldPulldown("_order", $this->params->order);
+        if (isset($this->request["set_id"])) {
+            $order = template::createInput("_order", "set_order");
+        } else {
+            $order=template::createPhotoFieldDropdown("_order", $this->params->order);
+        }
 
-        $rowsDropdown = template::createIntegerPulldown("_rows", $this->params->rows, 1, 20);
-        $colsDropdown = template::createIntegerPulldown("_cols", $this->params->cols, 1, 20);
+        $rowsDropdown = template::createIntegerDropdown("_rows", $this->params->rows, 1, 20);
+        $colsDropdown = template::createIntegerDropdown("_cols", $this->params->cols, 1, 20);
 
 
 
@@ -88,7 +82,7 @@ class display extends view {
             "sortdownurl"       => $sortdownurl
         ));
         $viewform->addHiddenFields($viewformvars);
-        $tpl=new template("displayPhotos", array(
+        $tpl=new block("displayPhotos", array(
             "title"             => $this->params->titleBar,
             "actionlinks"       => $this->getActionlinks(),
             "viewsettings"      => $viewform,
@@ -103,35 +97,11 @@ class display extends view {
         return $tpl;
     }
 
-   /**
-    * Set photo collection
-    * @param photo\collection photos for this view
-    */
-    public function setPhotos(photoCollection $photos) {
-        $this->photos = $photos;
-    }
-
-   /**
-    * Set photo collection to be displayed
-    * @param photo\collection photos to display
-    */
-    public function setDisplay(photoCollection $display) {
-        $this->display = $display;
-    }
-
-   /**
-    * Set photoids for the lightbox of the current user
-    * @param array|null of photoids
-    */
-    public function setLightbox(?array $lightbox) {
-        $this->lightbox = (array) $lightbox;
-    }
-
    /**
     * Get an array of thumbnails to display
     * @param array of @see template\block
     */
-    private function getThumbs() {
+    private function getThumbs() : array {
         $offset = $this->params->offset;
         $ignore = array("_action", "_photo_id");
         $thumbs = array();
@@ -153,11 +123,21 @@ class display extends view {
     * at this moment only to remove from lightbox
     * @return array links
     */
-    private function getThumbActionlinks() {
+    private function getThumbActionlinks() : array {
         $offset = $this->params->offset;
         $actionlinks = array();
         foreach ($this->display as $photo) {
-            if (array_search($photo->getId(), $this->lightbox) !== false) {
+            if (isset($this->request["set_id"])) {
+                $photoId = (int) $photo->getId();
+                $setId = (int) $this->request["set_id"];
+                $qs = $this->request->getEncodedQueryString();
+                $actionlinks[$offset] = new block("actionlinks", array(
+                    "actionlinks" => array(
+                        "x" => "set.php?_action=removephoto&set_id=" . $setId . "&_photo_id=" . $photoId .
+                               "&_qs=" . $qs
+                    )
+                ));
+            } else if (array_search($photo->getId(), $this->lightbox) !== false) {
                 $photoId = (int) $photo->getId();
                 $qs = $this->request->getEncodedQueryString();
                 $actionlinks[$offset] = new block("actionlinks", array(
@@ -178,7 +158,8 @@ class display extends view {
     * Get map to display with this page
     * @return geo\map map template
     */
-    private function getMap() {
+    private function getMap() : ?map {
+        $map = null;
         if (conf::get("maps.provider")) {
             $map=new map();
             foreach ($this->display as $photo) {
@@ -188,7 +169,7 @@ class display extends view {
                     $map->addMarker($marker);
                 }
             }
-            return $map;
         }
+        return $map;
     }
 }
