@@ -27,65 +27,92 @@ use search;
 use user;
 
 use conf\conf;
+use photo\collection as photoCollection;
 use photos\params;
 use web\request;
+use web\view\view as webView;
 
 /**
  * This is a base view for the photos page, that contains common parts for all views
  */
-abstract class view {
+abstract class view extends webView implements \view {
+
+    /* @var photo\collection photos for this request */
+    protected $photos;
+
+    /** @var photo\collection photos to display */
+    protected $display;
+
+    /** @var array of photo_ids that are in this user's lightbox */
+    protected $lightbox;
 
     /** * @var array request variables */
     protected $vars;
-    /** * @var request web request */
-    protected $request;
-    /** * @var photos\params interface data for page */
-    protected $params;
 
     /**
      * Create view
-     * @param request web request
      */
-    public function __construct(request $request, params $params) {
-        $this->request=$request;
-        $this->vars=$request->getRequestVars();
-        $this->params=$params;
+    public function __construct(protected request $request, protected params $params) {
     }
 
     /**
      * Get actionlinks
      */
-    protected function getActionlinks() {
+    protected function getActionlinks() : array {
         $user=user::getCurrent();
-        $qs=$this->request->getQueryString();
+        $qs=$this->request->cleanQueryString(array("/_crumb=\d+&?/", "/_action=\w+&?/"));
         $actionlinks=array();
-        if ($this->vars["_action"] ?? "display" == "search") {
+        if ($this->request["_action"] ?? "display" == "search") {
             $search = new search();
             $search->setSearchURL($this->request);
             $actionlinks[translate("save search")] = "search.php?_action=new&_qs=" . $search->getSearchQS();
+            $qs = urldecode($search->getSearchQS());
         }
         if ($user->isAdmin()) {
-            $actionlinks[translate("edit")] = "edit_photos.php?" . $qs;
-            $actionlinks[translate("geotag")] = "tracks.php?_action=geotag&" . $qs;
+            $actionlinks[translate("edit")] = "photos.php?_action=edit&" . $qs;
+            $actionlinks[translate("geotag")] = "track.php?_action=geotag&" . $qs;
         }
 
         $actionlinks[translate("slideshow")] = "slideshow.php?" . $qs;
 
         if (conf::get("feature.download") && ($user->get("download") || $user->isAdmin())) {
-            $actionlinks[translate("download")] = "download.php?" . $qs;
+            $actionlinks[translate("download")] = "photos.php?_action=download&" . $qs;
+        }
+
+        if (conf::get("feature.sets") && $user->isAdmin() && !isset($this->request["set_id"])) {
+            $actionlinks[translate("add to set")] = "set.php?_action=choose&" . $qs;
         }
         return $actionlinks;
     }
 
-    /**
-     * Output view
-     */
-    abstract public function view();
-
     /**
      * Get the title for this view
      */
-    public function getTitle() {
+    public function getTitle() :string {
         return $this->params->title;
     }
+
+   /**
+    * Set photo collection
+    * @param photo\collection photos for this view
+    */
+    public function setPhotos(photoCollection $photos) : void {
+        $this->photos = $photos;
+    }
+
+   /**
+    * Set photo collection to be displayed
+    * @param photo\collection photos to display
+    */
+    public function setDisplay(photoCollection $display) : void {
+        $this->display = $display;
+    }
+
+   /**
+    * Set photoids for the lightbox of the current user
+    * @param array|null of photoids
+    */
+    public function setLightbox(?array $lightbox) : void {
+        $this->lightbox = (array) $lightbox;
+    }
 }
