@@ -44,7 +44,7 @@ use template\template;
  * @author Jason Geiger
  * @author Jeroen Roos
  */
-class place extends zophTreeTable implements Organizer {
+class place extends zophTreeTable implements organizer {
 
     use showPage;
 
@@ -171,9 +171,21 @@ class place extends zophTreeTable implements Organizer {
             $user=user::getCurrent();
         }
         $count=$this->getTotalPhotoCount();
-        return ($count > 0 || $user->isCreator($this) || $user->isAdmin());
+        return ($count > 0 || $user->isCreator($this) || $user->isAdmin() || $user->canSeeAllPhotos() );
     }
 
+    /**
+     * Can user edit this place
+     * No specific user rights, so we simply return whether
+     * this user can edit places or not.
+     * @param user user
+     * @return bool can edit
+     */
+    public function isWritableBy(user $user) {
+        return $user->canEditOrganizers();
+    }
+
+    /**
 
     /**
      * Get children of this place
@@ -273,6 +285,20 @@ class place extends zophTreeTable implements Organizer {
         if ($this->get("country")) {
             $address[]=e($this->get("country"));
         }
+
+        if ($this->get("url")) {
+            $address[] = "";
+            $address[] = new block("link", array(
+                "href" => e($this->get("url")),
+                "link" => e($this->get("urldesc"))
+            ));
+        }
+
+        if ($this->get("timezone")) {
+            $address[] = "";
+            $address[] = $this->get("timezone");
+        }
+
         $tpl=new block("multiline", array(
             "class" => "address",
             "lines" => $address
@@ -280,22 +306,6 @@ class place extends zophTreeTable implements Organizer {
         return $tpl;
     }
 
-    /**
-     * Display this place's data
-     * @todo returns HTML
-     */
-    public function toHTML() {
-
-        $html = $this->getAddress();
-        if ($this->get("url")) {
-            $html .= "<br><br>\n";
-            $html .= "<a href=\"" . e($this->get("url")) . "\">";
-            $html .= e($this->get("urldesc")) . "</a>";
-        }
-
-        return $html;
-    }
-
     /**
      * Return an array with this place's data
      */
@@ -451,7 +461,7 @@ class place extends zophTreeTable implements Organizer {
         if ($result) {
             return $result->fetch(PDO::FETCH_ASSOC);
         } else {
-            return null;
+            return array();
         }
     }
 
@@ -459,8 +469,8 @@ class place extends zophTreeTable implements Organizer {
      * Turn the array from @see getDetails() into XML
      * @param array Don't fetch details, but use the given array
      */
-    public function getDetailsXML(array $details=null) {
-        if (!isset($details)) {
+    public function getDetailsXML(array $details = array()) {
+        if (empty($details)) {
             $details=$this->getDetails();
         }
         $details["title"]=translate("In this place:", false);
@@ -675,11 +685,11 @@ class place extends zophTreeTable implements Organizer {
 
 
     /**
-     * Create pulldown for zoom
+     * Create dropdown for zoom
      * @param int current value
      * @param name name for select box
      */
-    public static function createZoomPulldown($val = "", $name = "mapzoom") {
+    public static function createZoomDropdown($val = "", $name = "mapzoom") {
         $zoom_array = array(
             "0" => translate("0 - world", 0),
             "1" => translate("1",0),
@@ -701,7 +711,7 @@ class place extends zophTreeTable implements Organizer {
             "17" => translate("17",0),
             "18" => translate("18 - house",0));
 
-        return template::createPulldown($name, $val, $zoom_array);
+        return template::createDropdown($name, $val, $zoom_array);
     }
 }
 
