@@ -321,12 +321,12 @@ class rating extends zophTable {
     }
 
     /**
-     * Create a pulldown to select ratings
+     * Create a dropdown to select ratings
      * @param string name
      * @param int value to make 'selected'
-     * @return block pulldown template block
+     * @return block dropdown template block
      */
-    public static function createPulldown($name = "rating", $val = null) {
+    public static function createDropdown($name = "rating", $val = null) {
         $ratingArray = array(
             "1" => translate("1 - close your eyes", 0),
             "2" => translate("2", 0),
@@ -343,6 +343,6 @@ class rating extends zophTable {
             $ratingArray = array("0" => translate("not rated", 0)) + $ratingArray;
         }
 
-        return template::createPulldown($name, $val, $ratingArray, false, "zRating.ratingButton(\"ratingsubmit\", \"rating\")");
+        return template::createDropdown($name, $val, $ratingArray, false, "zRating.ratingButton(\"ratingsubmit\", \"rating\")");
     }
 }
