@@ -41,7 +41,7 @@ class report {
         $album= album::getRoot();
         $category = category::getRoot();
 
-        $size=template::getHumanReadableBytes(photo::getTotalSize());
+        $size=template::getHumanReadableBytes((int) photo::getTotalSize());
         return array(
             translate("number of photos") => photo::getCount(),
             translate("size of photos") => "$size",
