@@ -119,21 +119,12 @@ class search extends zophTable {
      * @param request web request
      */
     public function setSearchURL(request $request) {
-        $vars=$request->getRequestVarsClean();
-        unset($vars["_action"]);
-        unset($vars["_crumb"]);
-
-        $urlVars=array();
-
-        foreach ($vars as $key => $val) {
-            // Change key#0 into key[0]:
-            $key=preg_replace("/\#([0-9]+)/", "[$1]", $key);
-            // Change key[0]-children into key_children[0] because everything
-            // after ] in a variable name is lost fix for bug#2890387
-            $key=preg_replace("/\[(.+)\]-([a-z]+)/", "_$2[$1]", $key);
-            $urlVars[]=e($key) . "=" . e($val);
+        $vars=$request->getRequestVarsClean(array("_action"));
+        if (isset($vars["_qs"])) {
+            $this->set("search", $request->getPassedQueryString());
+        } else {
+            $this->set("search", http_build_query($vars));
         }
-        $this->set("search", implode("&amp;", $urlVars));
 
     }
 
