@@ -34,7 +34,12 @@ use template\block;
  * @package Zoph
  */
 class selection {
+    /** @var array Photos in the selection  */
     private $photos=array();
+    /** @var array The links that need to be displayed with each photo */
+    private $links=array();
+    /** @var photo|Organizer the currently displayed object */
+    private $obj = null;
 
     /**
      * Create a new selection object
@@ -44,22 +49,21 @@ class selection {
      *              be the url to which the user is redirected back
      *              afterwards.
      */
-    public function __construct($session, $links, photo $thisPhoto=null) {
+    public function __construct($session, $links, zophTable $current = null) {
         if (!isset($session["selected_photo"]) || sizeof($session["selected_photo"])===0) {
-            throw new PhotoNoSelectionException("No photos selected");
+            throw new photoNoSelectionException("No photos selected");
         }
 
         $this->links=$links;
+        $this->obj=$current;
 
         foreach ($session["selected_photo"] as $photo_id) {
-            if ($thisPhoto && $thisPhoto->getId() != $photo_id) {
-                $photo=new photo($photo_id);
-                $photo->lookup();
-                $this->photos[]=$photo;
-            }
+            $photo=new photo($photo_id);
+            $photo->lookup();
+            $this->photos[]=$photo;
         }
         if (sizeof($this->photos) === 0) {
-            throw new PhotoNoSelectionException("No photos selected");
+            throw new photoNoSelectionException("No photos selected");
         }
 
     }
@@ -76,8 +80,10 @@ class selection {
 
         foreach ($this->photos as $photo) {
             $actionlinks=array();
-            foreach ($links as $title => $link) {
-                $actionlinks[$title] = $link . $photo->getId() . "&amp;" . $return;
+            if (!($this->obj instanceof photo && ($this->obj->getId() == $photo->getId()))) {
+                foreach ($links as $title => $link) {
+                    $actionlinks[$title] = $link . $photo->getId() . "&amp;" . $return;
+                }
             }
             $actionlinks["x"] = "photo.php?_action=deselect&amp;photo_id=" . $photo->getId() . "&amp;" . $return;
 
