@@ -24,6 +24,7 @@
 namespace slideshow;
 
 use conf\conf;
+use generic\controller as genericController;
 use photo\collection;
 use web\request;
 
@@ -34,7 +35,9 @@ use user;
 /**
  * Controller for slideshow
  */
-class controller {
+class controller extends genericController {
+    protected static $viewDisplay   = view\display::class;
+
     /** @var request holds request */
     protected   $request;
 
@@ -53,13 +56,15 @@ class controller {
 
         $photoCount=sizeof($photoCollection);
 
+        $this->doAction();
+
     }
 
     /**
      * Do action 'display'
      */
     public function actionDisplay() {
-        $this->view="display";
+        $this->view=new static::$viewDisplay($this->request);
     }
 
 }
