@@ -24,39 +24,34 @@
 namespace slideshow\view;
 
 use conf\conf;
-use template\template;
+use template\block;
 use web\request;
-
+use web\view\view;
 use user;
 
 /**
  * This view displays a slideshow
  */
-class display {
+class display extends view implements \view {
     /** * @var array request variables */
     private $vars;
 
-    /** * @var request web request */
-    private $request;
-
-
     /**
      * Create view
      * @param request web request
      */
-    public function __construct(request $request) {
-        $this->request=$request;
+    public function __construct(protected request $request) {
         $this->vars=$request->getRequestVars();
     }
 
     /**
      * Output view
      */
-    public function view() {
+    public function view() : block {
 
         $user = user::getCurrent();
 
-        $tpl = new template("slideshow", array(
+        $tpl = new block("slideshow", array(
         "javascript" => "var duration=" . (int) $user->prefs->get("slideshow_time") . ";"
     ));
 
@@ -65,7 +60,7 @@ class display {
 
     }
 
-    public function getTitle() {
+    public function getTitle() : string {
         return "Slideshow";
     }
 }
