@@ -43,7 +43,7 @@ class colorScheme extends \zophTable {
                   the db with auto_increment */
     protected static $keepKeys = false;
     /** @var string URL for this class */
-    protected static $url="color_schemes.php?color_scheme_id=";
+    protected static $url="color_scheme.php?color_scheme_id=";
 
     /** @var colorScheme the currently loaded scheme */
     private static $current=null;
@@ -118,7 +118,7 @@ class colorScheme extends \zophTable {
 
     private function removeOctothorpe() {
         foreach ($this->fields as $field => $value) {
-            $this->set($field, str_replace("#", "", $value));
+            $this->set($field, str_replace("#", "", $value ?? ""));
         }
     }
     /**
@@ -142,20 +142,20 @@ class colorScheme extends \zophTable {
         }
     }
 
-    private static function getDefaults() {
+    public static function getDefaults() {
         return array(
-            "page_bg_color"             => "#ffffff",
+            "page_bg_color"             => "#445577",
             "text_color"                => "#000000",
             "link_color"                => "#111111",
             "vlink_color"               => "#444444",
-            "table_bg_color"            => "#ffffff",
+            "table_bg_color"            => "#eeeeee",
             "table_border_color"        => "#000000",
-            "breadcrumb_bg_color"       => "#ffffff",
-            "title_bg_color"            => "#f0f0f0",
-            "title_font_color"          => "#000000",
-            "tab_bg_color"              => "#000000",
-            "tab_font_color"            => "#ffffff",
-            "selected_tab_bg_color"     => "#c0c0c0",
+            "breadcrumb_bg_color"       => "#eeeeee",
+            "title_bg_color"            => "#bbbbcc",
+            "title_font_color"          => "#333333",
+            "tab_bg_color"              => "#667799",
+            "tab_font_color"            => "#000000",
+            "selected_tab_bg_color"     => "#bbbbcc",
             "selected_tab_font_color"   => "#000000"
         );
     }
