@@ -26,7 +26,6 @@ namespace template\colorScheme\view;
 use conf\conf;
 use template\colorScheme;
 use template\block;
-use template\template;
 use web\request;
 
 use user;
@@ -34,38 +33,22 @@ use user;
 /**
  * This view displays the "colorScheme" page
  */
-class display {
-    /** * @var array request variables */
-    protected $vars;
-    /** * @var request web request */
-    protected $request;
-    /** * @var colorScheme */
-    protected $colorScheme;
-
-    /**
-     * Create view
-     * @param web\request web request
-     * @param template\colorScheme the color scheme that this page is dealing with
-     */
-    public function __construct(request $request, colorScheme $colorScheme) {
-        $this->request=$request;
-        $this->vars=$request->getRequestVars();
-        $this->colorScheme=$colorScheme;
-    }
+class display extends view implements \view {
     /**
      * Get action links
      * @return array action links
      */
-    protected function getActionlinks() {
+    protected function getActionlinks() : array {
         if  (user::getCurrent()->isAdmin()) {
             return array(
                 translate("edit")   => "color_scheme.php?_action=edit&amp;color_scheme_id=" .
-                    $this->colorScheme->getId(),
+                    $this->object->getId(),
                 translate("copy") => "color_scheme.php?_action=copy&amp;color_scheme_id=" .
-                    $this->colorScheme->getId(),
+                    $this->object->getId(),
                 translate("delete") => "color_scheme.php?_action=delete&amp;color_scheme_id=" .
-                    $this->colorScheme->getId(),
-                translate("new")    => "color_scheme.php?_action=new"
+                    $this->object->getId(),
+                translate("new")    => "color_scheme.php?_action=new",
+                translate("return")    => "color_scheme.php?_action=displayAll"
             );
         } else {
             return array();
@@ -75,13 +58,13 @@ class display {
     /**
      * Output view
      */
-    public function view() {
-        $tpl = new template("main", array(
+    public function view() : block {
+        $tpl = new block("main", array(
             "title" =>  $this->getTitle()
         ));
 
         $tpl->addBlock(new block("displayColorScheme", array(
-            "colors"    =>  $this->colorScheme->getDisplayArray()
+            "colors"    =>  $this->object->getDisplayArray()
         )));
 
         $tpl->addActionlinks($this->getActionlinks());
@@ -89,8 +72,4 @@ class display {
         return $tpl;
 
     }
-
-    public function getTitle() {
-        return $this->colorScheme->getName();
-    }
 }
