@@ -26,7 +26,6 @@ namespace template\colorScheme\view;
 use template\block;
 use template\colorScheme;
 use template\form;
-use template\template;
 use web\request;
 
 use user;
@@ -34,35 +33,24 @@ use user;
 /**
  * This view displays the color scheme page when editing
  */
-class update {
-    /**
-     * Create view
-     * @param request web request
-     * @param colorScheme the color scheme that this page is dealing with
-     */
-    public function __construct(request $request, colorScheme $colorScheme) {
-        $this->request=$request;
-        $this->vars=$request->getRequestVars();
-        $this->colorScheme=$colorScheme;
-    }
-
+class update extends view implements \view {
     /**
      * Create the actionlinks for this page
      * @return array action links
      */
-    protected function getActionlinks() {
+    protected function getActionlinks() : array {
         return array(
-            "return"    => "color_schemes.php",
+            translate("return")    => "color_scheme.php?_action=displayAll",
         );
     }
 
     /**
      * Output the view
      */
-    public function view() {
+    public function view() : block {
         $user = user::getCurrent();
 
-        $action = $this->vars["_action"];
+        $action = $this->request["_action"];
         if ($action == "copy" || $action == "new") {
             $action = "insert";
         } else if ($action == "edit") {
@@ -76,29 +64,29 @@ class update {
             "submit"        => translate("save")
         ));
 
-        $form->addInputHidden("color_scheme_id", $this->colorScheme->getId());
+        $form->addInputHidden("color_scheme_id", $this->object->getId());
 
-        $name = $this->colorScheme->getName();
+        $name = $this->object->getName();
 
         $form->addInputText("name", $name, "name", "", 64, 16);
 
         $form->addBlock(new block("editColorScheme", array(
-            "colors"    => $this->colorScheme->getColors()
+            "colors"    => $this->object->getColors()
         )));
 
-        $tpl = new template("main", array(
-            "actionlinks"   => $this->getActionlinks(),
+        $tpl = new block("main", array(
             "title"     => $this->getTitle()
         ));
+        $tpl->addActionlinks($this->getActionlinks());
         $tpl->addBlock($form);
         return $tpl;
     }
 
-    public function getTitle() {
-        if ($this->vars["_action"] == "new") {
+    public function getTitle() : string {
+        if ($this->request["_action"] == "new") {
             return translate("New Color Scheme");
         }
-        return $this->colorScheme->getName();
+        return $this->object->getName();
     }
 
 }
