@@ -43,6 +43,19 @@ class form extends block {
         $this->addBlock(template::createInput($name, $value, $maxlength, $label, $size, $hint));
     }
 
+    /**
+     * Add a form field INPUT type email
+     * @param string name
+     * @param string current / initial value
+     * @param string label text for label
+     * @param string input hint
+     * @param int maximum input length
+     * @param int size of the field
+     */
+    public function addInputEmail($name, $value, $label=null) {
+        $this->addBlock(template::createInputEmail($name, $value, $label));
+    }
+
     /**
      * Add a form field INPUT type password
      * @param string name
@@ -74,10 +87,20 @@ class form extends block {
    /**
     * Add hidden fields to this form
     * @param array array of key -> value pairs to make into hidden fields
+    * @param array array of keys that should not be included
     */
-    public function addHiddenFields(array $vars) {
+    public function addHiddenFields(array $vars, array $ignore = array()) {
         foreach ($vars as $key => $val) {
-            $this->addInputHidden($key, $val);
+            if (!in_array($key, $ignore)) {
+                if (is_array($val)) {
+                    foreach ($val as $i => $v) {
+                        $this->addInputHidden($key . "[" . $i . "]", $v);
+                    }
+
+                } else {
+                    $this->addInputHidden($key, $val);
+                }
+            }
         }
     }
 
@@ -123,8 +146,8 @@ class form extends block {
      * @param block dropdown
      * @param string label text for label
      */
-    public function addPulldown($name, block $dropdown, $label) {
-        $this->addBlock(new block("formPulldown", array(
+    public function addDropdown($name, block $dropdown, $label) {
+        $this->addBlock(new block("formDropdown", array(
             "name"      => $name,
             "dropdown"  => $dropdown,
             "label"     => $label
@@ -139,4 +162,17 @@ class form extends block {
         $this->addBlock($fieldset);
     }
 
+    /**
+     * Create a form label
+     * @param string id of field this label is for
+     * @param string label label text
+     */
+    public static function createLabel(string $for, string $label) {
+        return new block("formLabel", array(
+            "for"   => $for,
+            "label" => $label
+        ));
+    }
+
+
 }
