@@ -89,6 +89,7 @@ class template {
             log::msg("Illegal characters in template", log::FATAL, log::GENERAL);
         }
     }
+
     /**
      * Get image URL for specific template.
      * if the image does not exist in the current template, the default will be be returned
@@ -150,6 +151,13 @@ class template {
         $this->blocks[]=$page;
     }
 
+    /**
+     * Add a break
+     */
+    public function addBreak() {
+        $this->blocks[]=new block("br", array());
+    }
+
     /**
      * Add multiple blocks
      * @param array Blocks to be added
@@ -238,12 +246,12 @@ class template {
     }
 
     /**
-     * Creates an array to be used in the createPulldown methods.  The
+     * Creates an array to be used in the createDropdown methods.  The
      * values of the fields in the name_fields parameter are concatentated
      * together to construnct the titles of the selections.
      * @param array Records to be processed
      * @param array fields to use to contruct title
-     * @return array Array that can be fed to the createPulldown methods.
+     * @return array Array that can be fed to the createDropdown methods.
      */
     public static function createSelectArray(array $records, array $name_fields, $addEmpty=false) {
         if (empty($records) || !$name_fields) {
@@ -273,6 +281,19 @@ class template {
         return $sa;
     }
 
+    public static function createInputDate($name, $value, $label=null) {
+        return static::createInput($name, $value, label: $label, type: "date");
+    }
+    public static function createInputTime($name, $value, $label=null) {
+        return static::createInput($name, $value, label: $label, type: "time");
+    }
+    public static function createInputEmail($name, $value, $label=null) {
+        return static::createInput($name, $value, maxlength: 64, size: 32, label: $label, type: "email");
+    }
+    public static function createInputNumber($name, $value, $label=null, $min = 0, $max = 100) {
+        $size = log10($max) + 5;
+        return static::createInput($name, $value, label: $label, type: "number", size: $size, min: $min, max: $max);
+    }
     /**
      * Create form input field
      * @param string name of the input
@@ -280,8 +301,12 @@ class template {
      * @param int maximum length
      * @param string label to be added
      * @param int|null display size, will be set from maxlength if null
+     * @param string hint - add some text after the input to help the user what to put there
+     * @param string type - html type [ text, date, time, ... ]
+     * @param int minimum value (only for type = number/range)
+     * @param int maximum value (only for type = number/range)
      */
-    public static function createInput($name, $value, $maxlength, $label=null, $size=null, $hint=null) {
+    public static function createInput($name, $value, $maxlength = 32, $label=null, $size=null, $hint=null, $type="text", $min = 0, $max = 100) {
         if (!$size) {
             $size=$maxlength;
         }
@@ -292,17 +317,20 @@ class template {
             "size"      => (int) $size,
             "maxlength" => (int) $maxlength,
             "hint"      => e($hint),
+            "type"      => $type,
+            "min"       => $min,
+            "max"       => $max
         ));
     }
 
     /**
-     * Create pulldown (select)
+     * Create dropdown (select)
      * @param string name for select box
      * @param string current value
      * @param array array of options
      * @param bool autosubmit form after making a change
      */
-    public static function createPulldown($name, $value, $selectArray, $autosubmit=false, $onchange=null) {
+    public static function createDropdown($name, $value, $selectArray, $autosubmit=false, $onchange=null) {
         return new block("select", array(
             "name"  => $name,
             "id"    => preg_replace("/^_+/", "", $name),
@@ -314,26 +342,26 @@ class template {
     }
 
     /**
-     * Create pulldown (select) to change the view
+     * Create dropdown (select) to change the view
      * @param string name for select box
      * @param string current value
      * @param bool autosubmit form after making a change
      */
-    public static function createViewPulldown($name, $value, $autosubmit=false) {
-        return static::createPulldown($name, $value, array(
+    public static function createViewDropdown($name, $value, $autosubmit=false) {
+        return static::createDropdown($name, $value, array(
             "list" => translate("List", 0),
             "tree" => translate("Tree", 0),
             "thumbs" => translate("Thumbnails", 0)), (bool) $autosubmit);
     }
 
     /**
-     * Create pulldown (select) to determine how the automatic thumbnail is selected
+     * Create dropdown (select) to determine how the automatic thumbnail is selected
      * @param string name for select box
      * @param string current value
      * @param bool autosubmit form after making a change
      */
-    public static function createAutothumbPulldown($name, $value, $autosubmit=false) {
-        return  static::createPulldown($name, $value, array(
+    public static function createAutothumbDropdown($name, $value, $autosubmit=false) {
+        return  static::createDropdown($name, $value, array(
             "oldest" => translate("Oldest photo", 0),
             "newest" => translate("Newest photo", 0),
             "first" => translate("Changed least recently", 0),
@@ -344,16 +372,16 @@ class template {
     }
 
     /**
-     * Create pulldown (select) that lists all photo fields
+     * Create dropdown (select) that lists all photo fields
      * @param string name for select box
      * @param string current value
      */
-    public static function createPhotoFieldPulldown($name, $value) {
-        return  static::createPulldown($name, $value, translate(photo::getFields(), 0));
+    public static function createPhotoFieldDropdown($name, $value) {
+        return  static::createDropdown($name, $value, translate(photo::getFields(), 0));
     }
 
-    public static function createPhotoTextPulldown($name, $value) {
-        return template::createPulldown($name, $value, array(
+    public static function createPhotoTextDropdown($name, $value) {
+        return template::createDropdown($name, $value, array(
             "" => "",
             "album" => translate("album", 0),
             "category" => translate("category", 0),
@@ -362,21 +390,21 @@ class template {
     }
 
     /**
-     * Create pulldown (select) that lists photo fields for the import page
+     * Create dropdown (select) that lists photo fields for the import page
      * @param string name for select box
      * @param string current value
      */
-    public static function createImportFieldPulldown($name, $value) {
-        return  static::createPulldown($name, $value, translate(photo::getImportFields(), 0));
+    public static function createImportFieldDropdown($name, $value) {
+        return  static::createDropdown($name, $value, translate(photo::getImportFields(), 0));
     }
 
     /**
-     * Create comparison operator pulldown, tailored for text comparison
+     * Create comparison operator dropdown, tailored for text comparison
      * @param string name for select box
      * @param string current value
      */
-    public static function createTextOperatorPulldown($name, $value = "=") {
-        return static::createPulldown($name, $value,
+    public static function createTextOperatorDropdown($name, $value = "=") {
+        return static::createDropdown($name, $value,
             array(
                 "="     => "=",
                 "!="    => "!=",
@@ -386,12 +414,12 @@ class template {
     }
 
     /**
-     * Create comparison operator pulldown
+     * Create comparison operator dropdown
      * @param string name for select box
      * @param string current value
      */
-    public static function createOperatorPulldown($name, $value = "=") {
-        return static::createPulldown($name, $value,
+    public static function createOperatorDropdown($name, $value = "=") {
+        return static::createDropdown($name, $value,
             array(
                 "="     => "=",
                 "!="    => "!=",
@@ -405,29 +433,29 @@ class template {
     }
 
     /**
-     * Create inequality operator [less than/more than] pulldown
+     * Create inequality operator [less than/more than] dropdown
      * @param string name for select box
      * @param string current value
      */
-    public static function createInequalityOperatorPulldown($name, $value = "") {
-        return template::createPulldown($name, $value,
+    public static function createInequalityOperatorDropdown($name, $value = "") {
+        return template::createDropdown($name, $value,
            array(">" => translate("less than"), "<" => translate("more than")));
     }
 
     /**
-     * Create pulldown (select) with options "yes" and "no" (translated)
+     * Create dropdown (select) with options "yes" and "no" (translated)
      * @param string name for select box
      * @param string current value
      */
-    public static function createBinaryOperatorPulldown($name, $value = "=") {
-        return  static::createPulldown($name, $value, array(
+    public static function createBinaryOperatorDropdown($name, $value = "=") {
+        return  static::createDropdown($name, $value, array(
             "=" => "=",
             "!=" => "!="
         ));
     }
 
-    public static function createPresentOperatorPulldown($name, $value = "=") {
-        return template::createPulldown($name, $value,
+    public static function createPresentOperatorDropdown($name, $value = "=") {
+        return template::createDropdown($name, $value,
             array(
                 "=" => translate("is in photo", 0),
                 "!=" => translate("is not in photo", 0)
@@ -436,33 +464,33 @@ class template {
 
 
     /**
-     * Create pulldown (select) with options "yes" and "no" (translated)
+     * Create dropdown (select) with options "yes" and "no" (translated)
      * @param string name for select box
      * @param string current value
      */
-    public static function createYesNoPulldown($name, $value) {
-        return  static::createPulldown($name, $value, array(
+    public static function createYesNoDropdown($name, $value) {
+        return  static::createDropdown($name, $value, array(
             "0" => translate("No", 0),
             "1" => translate("Yes", 0)
         ));
     }
 
     /**
-     * Create conjunction [and/or] pulldown
+     * Create conjunction [and/or] dropdown
      * @param string name for select box
      * @param string current value
      */
-    public static function createConjunctionPulldown($name, $value = "") {
-        return template::createPulldown($name, $value,
+    public static function createConjunctionDropdown($name, $value = "") {
+        return template::createDropdown($name, $value,
             array("" => "", "and" => translate("and", 0), "or" => translate("or", 0)));
     }
 
     /**
-     * Create pulldown with variable number of days
+     * Create dropdown with variable number of days
      * @param string name for select box
      * @param string current value
      */
-    public static function createDaysAgoPulldown($name, $value) {
+    public static function createDaysAgoDropdown($name, $value) {
         $dt=new Time(date("Y-m-d"));
         $dateArray=array("" => "");
 
@@ -472,20 +500,20 @@ class template {
             $dateArray[$dt->format("Y-m-d")] = $i;
         }
 
-        return template::createPulldown($name, $value, $dateArray);
+        return template::createDropdown($name, $value, $dateArray);
     }
 
     /**
-     * Create pulldown with integers
+     * Create dropdown with integers
      * @param string name for select box
      * @param string current value
      */
-    public static function createIntegerPulldown($name, $value, $min, $max) {
+    public static function createIntegerDropdown($name, $value, $min, $max) {
         $intArray=array();
         for ($i = $min; $i <= $max; $i++) {
             $intArray["$i"] = $i;
         }
-        return template::createPulldown($name, $value, $intArray);
+        return template::createDropdown($name, $value, $intArray);
     }
 
     /**
