@@ -25,7 +25,6 @@ namespace upgrade\view;
 
 use conf\conf;
 use upgrade\migrations;
-use upgrade\result;
 use template\block;
 use template\template;
 use web\request;
@@ -33,50 +32,25 @@ use web\request;
 /**
  * Display executed migrations
  */
-class upgrade {
+class upgrade extends view implements \view {
+    /** @var array completed migrations */
+    private $completeMigrations = array();
 
-    /** @var migrations migrations */
-    private $migrations;
-
-    /** @var string title */
-    private $title;
-
-    /**
-     * Create view
-     * @param request web request
-     * @param array results
-     */
-    public function __construct(request $request, array $migrations) {
-        $this->migrations = $migrations;
+    public function setComplete(array $complete) : void {
+        $this->completeMigrations=$complete;
     }
 
     /**
-     * Get headers, always null, as default headers are used
-     * @return null
+     * Retuirn the view
+     * @return template\block upgrade view
      */
-    public function getHeaders() {
-        return null;
-    }
-
-    /**
-     * Retrun the view
-     * @return template\template upgrade view
-     */
-    public function view() {
-        return new template("upgrade", array(
+    public function view() : block {
+        return new block("upgrade", array(
             "title"         => conf::get("interface.title"),
             "version"       => VERSION,
-            "migrations"    => $this->migrations,
+            "migrations"    => $this->completeMigrations,
             "button"       => translate("finish"),
             "button_url"   => "zoph.php"
         ));
     }
-
-    /**
-     * Get title
-     * @return string title
-     */
-    public function getTitle() {
-        return $this->title ?: translate("Zoph Upgrade");
-    }
 }
