@@ -27,6 +27,7 @@ use db\clause;
 use db\param;
 use db\selectHelper;
 use conf\conf;
+use user\prefs;
 
 /**
  * A class representing a user of Zoph
@@ -55,7 +56,7 @@ class user extends zophTable {
 
     /** @var person Person linked to this user */
     public $person;
-    /** @var \userPrefs Preferences of this user */
+    /** @var prefs Preferences of this user */
     public $prefs;
     /** @var \language Holds translations */
     public $lang;
@@ -424,7 +425,7 @@ class user extends zophTable {
         );
     }
 
-    public function getAccessRightsDescription() {
+    public static function getAccessRightsDescription() {
         return array(
             "view_all_photos"       => translate("can view all photos"),
             "delete_photos"         => translate("can delete photos"),
@@ -497,6 +498,22 @@ class user extends zophTable {
         }
     }
 
+    /**
+     * Check if user exists
+     * @param string username
+     * @return bool user exists
+     */
+    public static function exists(string $name) {
+        try {
+            self::getByName($name);
+        } catch (userNotFoundException $e) {
+            return false;
+        } catch (userMultipleFoundException $e) {
+            return true;
+        }
+        return true;
+    }
+
     /**
      * Get all users
      * @param string sort order
@@ -510,10 +527,8 @@ class user extends zophTable {
      * Set currently logged in user
      * (log in)
      * @param user user object
-     * @todo a proper framework needs to be made to invalidate caches
      */
     public static function setCurrent(user $user) {
-        category::$categoryCache=null;
         $user->lookup();
         $user->lookupPrefs();
         $user->lookupPerson();
