@@ -23,18 +23,40 @@
 
 namespace web\service\view;
 
+use web\request;
+
 /**
- * This view displays the "photo" page
+ * This view displays json data
  */
-class json {
+class json implements \view {
 
     private $data = array();
 
-    public function __construct(array $data) {
+    public function __construct(request $request, array $data) {
+        $this->request = $request;
         $this->data = $data;
     }
 
-    public function view() {
+    public function view() : string {
         return json_encode($this->data);
     }
+
+    public function display($template = "json") : void {
+        foreach ($this->getHeaders() as $header) {
+            header($header);
+        }
+        echo $this->view();
+    }
+
+    public function getActionlinks() : ?array {
+        return null;
+    }
+
+    public function getHeaders() : ?array {
+        return array("Content-Type: application/json");
+    }
+
+    public function getTitle() : string {
+        return "";
+    }
 }
