@@ -23,6 +23,8 @@
 
 namespace web;
 
+use conf\conf;
+
 /**
  * The url object represents an http URL
  *
@@ -35,6 +37,14 @@ class url {
      * Get Zoph's URL
      */
     public static function get() {
+        $override = conf::get("share.url.override");
+        if (!empty($override)) {
+            if (substr($override, -1) != "/") {
+                $override .= "/";
+            }
+            return $override;
+        }
+
         $request = request::create();
         $https = $request->getServerVar("HTTPS");
         if ($https && !empty($https) && $https != "off") {
