@@ -134,10 +134,10 @@ class tag {
             new tag("background", "div", "", "class='background' style=\"background: [param];\""),
             new tag("photo", "a", "", "href=\"photo.php?photo_id=[param]\""),
             new tag("album", "a", "", "href=\"album.php?album_id=[param]\""),
-            new tag("person", "a", "", "href=\"people.php?person_id=[param]\""),
+            new tag("person", "a", "", "href=\"person.php?person_id=[param]\""),
             new tag("cat", "a", "", "href=\"category.php?category_id=[param]\""),
             new tag("link", "a", "", "href=\"[param]\""),
-            new tag("place", "a", "", "href=\"places.php?parent_place_id=[param]\""),
+            new tag("place", "a", "", "href=\"place.php?place_id=[param]\""),
             new tag("thumb", "img", "", "src=\"image.php?photo_id=[param]&type=thumb\"", false),
             new tag("mid", "img", "", "src=\"image.php?photo_id=[param]&type=mid\"", false)
         );
