@@ -24,14 +24,15 @@
  * @package Zoph
  */
 
-use db\select;
+use db\clause;
 use db\db;
+use db\delete;
+use db\exception as databaseException;
 use db\insert;
 use db\param;
-use db\update;
 use db\query;
-use db\clause;
-use db\delete;
+use db\select;
+use db\update;
 
 use conf\conf;
 
@@ -128,7 +129,6 @@ abstract class zophTable {
     public function setFields(array $vars, $prefix = null, $suffix = null, $null=true) {
         foreach ($vars as $key => $val) {
             log::msg("<b>" . $key . "</b> = " . implode(",", (array) $val), log::DEBUG, log::VARS);
-
             // ignore empty keys or values unless the field must be set.
 
             if ($null) {
@@ -162,8 +162,15 @@ abstract class zophTable {
 
             // something in ALL CAPS is probably PHP or HTML related
             if (strtoupper($key) == $key) { continue; }
-
-            $this->fields[$key] = stripslashes($val);
+            try {
+                if (empty($val)) {
+                    $this->fields[$key] = $val;
+                } else {
+                    $this->fields[$key] = stripslashes($val);
+                }
+            } catch (TypeError $e) {
+                log::msg("<b>" . $key . "</b>: unexpected value", log::FATAL, log::VARS);
+            }
 
         }
     }
@@ -409,8 +416,8 @@ abstract class zophTable {
      * Turn the array from @see getDetails() into XML
      * @param array Don't fetch details, but use the given array
      */
-    public function getDetailsXML(array $details=null) {
-        if (!isset($details)) {
+    public function getDetailsXML(array $details = array()) {
+        if (empty($details)) {
             $details=$this->getDetails();
         }
         if (isset($details["title"])) {
@@ -596,6 +603,9 @@ abstract class zophTable {
      */
     public static function getFromVars(array $vars, $suffix="") {
         $class=get_called_class();
+        if ($class == "set\model") {
+            $class = "set";
+        }
         $return=array();
 
         $key="_" . $class . $suffix;
@@ -625,7 +635,7 @@ abstract class zophTable {
         try {
             $result = db::query($qry);
         } catch (PDOException $e) {
-            log::msg("Unable to get records: " . $e->getMessage(), log::FATAL, log::DB);
+            throw new databaseException("Unable to get records: " . $e->getMessage());
         }
         $objs=array();
         while ($row = $result->fetch(PDO::FETCH_ASSOC)) {
@@ -701,7 +711,7 @@ abstract class zophTable {
      * @param string Search string
      */
     public static function getXML($search) {
-        $search=strtolower($search);
+        $search=$search ? strtolower($search) : null;
 
         $xml = new DOMDocument('1.0','UTF-8');
         $rootnode=$xml->createElement(static::XMLROOT);
@@ -718,24 +728,24 @@ abstract class zophTable {
     }
 
     /**
-     * Create a pulldown menu for this object
-     * @param string name for this pulldown
+     * Create a dropdown menu for this object
+     * @param string name for this dropdown
      * @param int|string id of value
      */
-    public static function createPulldown($name, $value=null) {
+    public static function createDropdown($name, $value=null) {
         if (static::getAutocompPref()) {
-            return static::createAutoCompPulldown($name, $value);
+            return static::createAutoCompDropdown($name, $value);
         } else {
             if (isset(static::$sacache)) {
                 $sa=static::$sacache;
             } else {
                 $sa=static::getSelectArray();
             }
-            return template::createPulldown($name, $value, $sa);
+            return template::createDropdown($name, $value, $sa);
         }
     }
 
-    public static function createAutoCompPulldown($name, $value=null) {
+    public static function createAutoCompDropdown($name, $value=null) {
         $id=preg_replace("/^_+/", "", $name);
         $text="";
         if ($value) {
