@@ -138,6 +138,19 @@ abstract class zophTreeTable extends zophTable {
         }
     }
 
+    /**
+     * Gets an array of links to ancestors
+     * @return array ancestor name => url
+     */
+    public function getAncestorLinks() {
+        $links=array();
+        foreach (array_reverse($this->getAncestors()) as $ancestor) {
+            $links[$ancestor->getName()] = $ancestor->getURL();
+        }
+        return $links;
+    }
+
+
     /**
      * Get all ancestors of this a list of records, in order to get
      * all viewable records
@@ -205,8 +218,8 @@ abstract class zophTreeTable extends zophTable {
         $newchild=$xml->createElement($nodename);
 
         $title=$this->getName();
-        $titleshort=strtolower(substr($title, 0, strlen($search)));
-        if ($titleshort == strtolower($search)) {
+        $titleshort=$search ? strtolower(substr($title, 0, strlen($search))) : null;
+        if ($titleshort == ($search ? strtolower($search) : null)) {
             $key=$this->get($idname);
 
             $newchildkey=$xml->createElement("key");
@@ -237,8 +250,8 @@ abstract class zophTreeTable extends zophTable {
      * Turn the array from @see getDetails() into XML
      * @param array Don't fetch details, but use the given array
      */
-    public function getDetailsXML(array $details=null) {
-        if (!isset($details)) {
+    public function getDetailsXML(array $details = array()) {
+        if (empty($details)) {
             $details=$this->getDetails();
         }
         $children=$this->getChildren();
