@@ -27,27 +27,6 @@ use web\request;
 
 require_once "include.inc.php";
 
-$request = request::create();
-$controller = new controller($request);
-$colorScheme=$controller->getObject();
-switch ($controller->getView()) {
-case "confirm":
-    $view=new template\colorScheme\view\confirm($request, $colorScheme);
-    break;
-case "display":
-    $view=new template\colorScheme\view\display($request, $colorScheme);
-    break;
-case "insert":
-case "update":
-    $view=new template\colorScheme\view\update($request, $colorScheme);
-    break;
-case "redirect":
-    $view=new template\colorScheme\view\redirect($request, $colorScheme);
-    $view->setRedirect("color_schemes.php");
-    break;
-}
-$title = $view->getTitle();
-require_once "header.inc.php";
-echo $view->view();
-require_once "footer.inc.php";
-
+$controller = new controller(request::create());
+$view=$controller->getView();
+$view?->display();
