@@ -21,36 +21,16 @@
  * @author Jeroen Roos
  */
 
-use conf\conf;
-use template\template;
+use conf\controller;
+use web\request;
 
 require_once "include.inc.php";
-$title=translate("Configuration");
 
 if (!$user->isAdmin()) {
-    redirect("zoph.php");
+    redirect::redirect("zoph.php", "Admin account required");
 }
 
-// Configuration setting depends on POST
-if (!empty($_GET)) {
-    redirect("config.php");
-}
-
-$_action=getvar("_action");
-if ($_action == "setconfig") {
-    conf::loadFromRequestVars($request_vars);
-}
-
-$tpl=new template("config", array(
-    "title" => $title,
-));
-
-// this doesn't work yet, because the page is not fully template-generated
-// it is also included in header.inc.php, but header.inc.php should be
-// phased out soon.
-$tpl->js[]="js/conf.js";
-foreach (conf::getAll() as $name=>$item) {
-    $tpl->addBlock($item->display());
-}
-echo $tpl;
+$controller = new controller(request::create());
+$view=$controller->getView();
+$view->display();
 ?>
