@@ -19,16 +19,31 @@
 use conf\conf;
 
 header("Content-Type: text/css");
+try {
+    require_once "autoload.inc.php";
+    require_once "exception.inc.php";
+    require_once "config.inc.php";
+    $tpl=conf::get("interface.template");
+} catch (exception $e) {
+    $tpl = "default";
+}
 if (isset($_GET['logged_on'])) {
     define("LOGON", true);
     echo "/* This is the default CSS, the user is not logged on */";
     $cssfile="logon.css.php";
+} else if (isset($_GET['install'])) {
+    define("INSTALL", true);
+    settings::$php_loc = dirname($_SERVER['SCRIPT_FILENAME']);
+
+    $lang = new language("en");
+
+    echo "/* This is the install CSS, the user is not logged on */";
+    $cssfile="css.php";
 } else {
+    require_once "include.inc.php";
     echo "/* This is the customized CSS, user is logged on */";
     $cssfile="css.php";
 }
-require_once "include.inc.php";
-$tpl=conf::get("interface.template");
 $css="templates/" . $tpl . "/" . $cssfile;
 if (!file_exists($css)) {
     $css="templates/default/" . $cssfile;
