@@ -21,35 +21,17 @@
  * @author Jeroen Roos
  */
 
-use conf\conf;
-
 use group\controller as groupController;
-
-use template\block;
-use template\form;
-use template\template;
-
+use web\redirect;
 use web\request;
 
 
 require_once "include.inc.php";
 
 if (!user::getCurrent()->isAdmin()) {
-    redirect("zoph.php");
+    redirect::redirect("zoph.php", "Admin user required");
 }
 
 $controller = new groupController(request::create());
 $view = $controller->getView();
-
-$headers = $view->getHeaders();
-if (is_array($headers)) {
-    foreach ($headers as $header) {
-        header($header);
-    }
-    echo $view->view();
-} else {
-    $title = $view->getTitle();
-    require_once("header.inc.php");
-    echo $view->view();
-    require_once("footer.inc.php");
-}
+$view->display();
