@@ -21,24 +21,25 @@
  * @author Jason Geiger
  * @author Jeroen Roos
  */
+use db\exception as databaseException;
+use web\redirect;
 
-require_once "autoload.inc.php";
-
-require_once "exception.inc.php";
-require_once "log.inc.php";
-
-require_once "config.inc.php";
-require_once "settings.inc.php";
-require_once "requirements.inc.php";
-require_once "util.inc.php";
+try {
+    require_once "autoload.inc.php";
+    require_once "exception.inc.php";
+    require_once "config.inc.php";
+    if (!defined("CLI")) {
+        require_once "requirements.inc.php";
+    }
+} catch (configurationException $e) {
+    settings::$php_loc = dirname($_SERVER['SCRIPT_FILENAME']);
+    redirect::redirect("install.php", "Run install script");
+} catch (databaseException $e) {
+    settings::$php_loc = dirname($_SERVER['SCRIPT_FILENAME']);
+    redirect::redirect("install.php", "Run install script");
+}
 
 require_once "variables.inc.php";
+require_once "auth.inc.php";
 
-if (!defined("LOGON")) {
-    if (!defined("TEST")) {
-        require_once "auth.inc.php";
-    }
-
-    require_once "exif.inc.php";
-}
 ?>
