@@ -22,7 +22,7 @@ var zImport=function() {
 
         updateProgressbar(id + "_" + num);
         
-        div=document.getElementById("prog_" + id + "_" + num);
+        var div=document.getElementById("prog_" + id + "_" + num);
         div.style.display="block";
 
         num=parseInt(num, 10) + 1;
@@ -31,7 +31,7 @@ var zImport=function() {
     }
 
     function createUploadIframe(frame, id, num) {
-        iframe=document.createElement("iframe");
+        var iframe=document.createElement("iframe");
         iframe.src="import.php?_action=browse&num=" + num + "&upload_id=" + id;
         iframe.className="upload";
         iframe.id="upload_" + num;
@@ -41,7 +41,7 @@ var zImport=function() {
     }
 
     function deleteIframe(frame_id) {
-        frame=top.document.getElementById(frame_id);
+        var frame=top.document.getElementById(frame_id);
         frameparent=frame.parentNode;
         setTimeout('frameparent.removeChild(frame)', 10000);
     }
@@ -52,10 +52,11 @@ var zImport=function() {
     }
 
     function httpResponse(object, xml) {
-        root=xml.getElementsByTagName('importprogress');
-        importnode=root[0].firstChild;
-        id=importnode.firstChild.firstChild.nodeValue;
-        currentnode=importnode.childNodes[1];
+        var root=xml.getElementsByTagName('importprogress');
+        var importnode=root[0].firstChild;
+        var id=importnode.firstChild.firstChild.nodeValue;
+        var currentnode=importnode.childNodes[1];
+        var current, total, filename, percent;
         if(currentnode.childNodes.length===0) {
             current=0;
             total=0;
@@ -66,16 +67,15 @@ var zImport=function() {
             filename=importnode.childNodes[3].firstChild.nodeValue;
         }
         
-        
-        fn=document.getElementById("fn_" + id);
+        var fn=document.getElementById("fn_" + id);
         fn.innerHTML=filename;
 
-        MB = parseInt(parseInt(total, 10) / 1024 / 102.4, 10) / 10;
+        var MB = parseInt(parseInt(total, 10) / 1024 / 102.4, 10) / 10;
 
-        size=document.getElementById("sz_" + id);
+        var size=document.getElementById("sz_" + id);
         size.innerHTML=MB.toString() + " MiB";
 
-        progressdiv=document.getElementById("pb_" + id + "_inner");
+        var progressdiv=document.getElementById("pb_" + id + "_inner");
         if(total > 0) {
             percent = parseInt(
                 parseInt(current, 10) / parseInt(total,10) * 100,10);
@@ -134,25 +134,28 @@ var zImport=function() {
         var content;
         var status;
         var submit;
+        var imgsrc;
+        var importli;
+        var xmlimport;
 
         if (http.readyState == 4) {
             if(http.status == 200) {
-                response=http.responseXML;
-                thumbswindow=document.getElementById("import_thumbs");
-                thumbs=document.getElementById("import_thumbnails");
+                var response=http.responseXML;
+                var thumbswindow=document.getElementById("import_thumbs");
+                var thumbs=document.getElementById("import_thumbnails");
                 
-                files=response.getElementsByTagName("file");
-                ids=[];
+                var files=response.getElementsByTagName("file");
+                var ids=[];
                 if(files.length>0) {
                     thumbswindow.style.display="block";
                     for(var i=0; i<files.length; i++) {
-                        md5 = null;
+                        var md5 = null;
                         status = null;
-                        icon = null;
+                        var icon = null;
                         var subjects = Array();
-                        rating = null;
+                        var rating = null;
                         for(var c=0; c<files[i].childNodes.length; c++) {
-                            tag=files[i].childNodes[c];
+                            var tag=files[i].childNodes[c];
                             content=null;
                             content=tag.textContent;
                             switch(tag.nodeName) {
@@ -176,30 +179,30 @@ var zImport=function() {
                                 rating = parseInt(files[i].childNodes[c].textContent, 10)
                             }
                         }
-                        deleteli=document.createElement("li");
-                        actionlinks=document.createElement("ul");
+                        var deleteli=document.createElement("li");
+                        var actionlinks=document.createElement("ul");
                         
                         actionlinks.className="actionlink";
                         
-                        del=createNode("a", translate['delete']);
+                        var del=createNode("a", translate['delete']);
                         del.href="#";
                         del.setAttribute("onClick", "zImport.doAction('delete', '" + md5 + "'); return false");
                         deleteli.appendChild(del);
 
-                        retryli=document.createElement("li");
-                        retry=createNode("a", translate['retry']);
+                        var retryli=document.createElement("li");
+                        var retry=createNode("a", translate['retry']);
                         retry.href="#";
                         retry.setAttribute("onClick", "zImport.doAction('retry', '" + md5 + "'); return false");
                         retryli.appendChild(retry);
                         
                         actionlinks.appendChild(deleteli);
 
-                        checkbox=document.createElement("input");
+                        var checkbox=document.createElement("input");
                         checkbox.setAttribute("type", "checkbox");
                         checkbox.setAttribute("name", "cb_" + md5);
                         checkbox.className="thumb_checkbox";
                         
-                        existing=document.getElementById(md5);
+                        var existing=document.getElementById(md5);
                         if(existing) {
                             for(var e=0; e<existing.childNodes.length; e++) {
                                 tag=existing.childNodes[e];
@@ -219,16 +222,16 @@ var zImport=function() {
                             }
 
                         } else {
-                            div=document.createElement("div");
+                            var div=document.createElement("div");
                             div.id=md5;
                             div.className="thumbnail";
-                            name=files[i].getAttribute("name");
-                            type=files[i].getAttribute("type");
+                            var name=files[i].getAttribute("name");
+                            var type=files[i].getAttribute("type");
                             
-                            filename=createNode("span", name);
+                            var filename=createNode("span", name);
                             filename.className="filename";
 
-                            img=document.createElement("img");
+                            var img=document.createElement("img");
                             switch(status) {
                             case "done":
                                 if(type=="gpx") {
@@ -266,7 +269,7 @@ var zImport=function() {
                             var cat = 0;
                             for (var subject in subjects) {
                                 var categoryli=createNode("li", subjects[subject]);
-                                category = categories.filter(cat => cat.name.toLowerCase() == subjects[subject].toLowerCase() );
+                                var category = categories.filter(ctg => ctg.name.toLowerCase() == subjects[subject].toLowerCase() );
                                 if (category.length == 0) {
                                     categoryli.className="unknown";
                                 } else {
@@ -298,8 +301,7 @@ var zImport=function() {
                 }
                 // Remove all thumbs for which the file no longer
                 // exists
-                for(var t=0; t<thumbs.childNodes.length; t++) {
-                    thumb=thumbs.childNodes[t];
+                for(var thumb of thumbs.childNodes) {
                     if(thumb.className=="thumbnail") {
                         if(findInArray(ids,thumb.id)==-1) {
                             thumbs.removeChild(thumb);
@@ -309,10 +311,10 @@ var zImport=function() {
                 }
 
                 // Sort the nodes by Filename
-                names=getElementsByClass("filename");
-                oldfile="";
+                var names=getElementsByClass("filename");
+                var oldfile="";
                 for(var f=0; f<names.length; f++) {
-                    file=names[f].innerHTML;
+                    var file=names[f].innerHTML;
                     if(file<oldfile) {
                         for(var n=0; n<names.length; n++) {
                             if(file<names[n].innerHTML) {
@@ -335,18 +337,19 @@ var zImport=function() {
     }
 
     function processFiles() {
-        waiting=getElementsByClass("waiting");
-        busy=getElementsByClass("busy");
+        var waiting=getElementsByClass("waiting");
+        var busy=getElementsByClass("busy");
+
         if(parallel < 1) {
             parallel = 1;
         }
         if(waiting.length > 0 && busy.length < parallel) {
             busy=waiting[0];
             busy.className="busy";
-            thumbs=top.document.getElementById("import_thumbs");
+            var thumbs=top.document.getElementById("import_thumbs");
             thumbs.style.display="block";
-            md5=busy.parentNode.id;
-            filename=busy.nextSibling.innerHTML;
+            var md5=busy.parentNode.id;
+            var filename=busy.nextSibling.innerHTML;
 
             switch(getFileType(filename)) {
             case "image":
@@ -363,9 +366,9 @@ var zImport=function() {
 
     function processDone(html) {
         if(html) {
-            output=top.document.getElementById("import_details_text");
-            p=document.createElement("p");
-            t=document.createElement("p");
+            var output=top.document.getElementById("import_details_text");
+            var p=document.createElement("p");
+            var t=document.createElement("p");
             t.innerHTML=html;
             output.appendChild(p);
             p.innerHTML=t.innerHTML;
@@ -376,7 +379,7 @@ var zImport=function() {
     function doAction(action,md5) {
         var http=new XMLHttpRequest();
         http.open("GET", "import.php?_action=" + action + "&file=" + md5, true);
-        thumb=document.getElementById(md5);
+        var thumb=document.getElementById(md5);
         if(action=="delete" || action=="retry") {
             deleteNode(thumb);
         }
@@ -424,7 +427,7 @@ var zImport=function() {
         var submit;
         var toImport=0;
 
-        form=document.getElementById("import_form");
+        var form=document.getElementById("import_form");
         // Disable the submit button to prevent submitting twice
         // it will be reactivated after refreshing the thumbnails
 
@@ -432,7 +435,7 @@ var zImport=function() {
         submit.disabled=true;
 
         // Delete the old checkboxes, if any.
-        fieldset=document.getElementById("import_checkboxes");
+        var fieldset=document.getElementById("import_checkboxes");
         if(fieldset) {
             removeChildren(fieldset);
         } else {
@@ -441,14 +444,14 @@ var zImport=function() {
             form.appendChild(fieldset);
         }
         // Now copy the checkboxes from the form above into this form
-        images=getElementsByClass("thumb_checkbox");
+        var images=getElementsByClass("thumb_checkbox");
         for(var i=0; i<images.length; i++) {
             if(images[i].checked) {
-                input=document.createElement("input");
+                var input=document.createElement("input");
                 input.name="_import_image[" + toImport + "]";
                 input.className="import_image";
 
-                cb=images[i].name.split("_");
+                var cb=images[i].name.split("_");
                 input.value=cb[1];
                 fieldset.appendChild(input);
 
@@ -503,7 +506,7 @@ var zImport=function() {
     }
     
     function destroyPreviewDiv(md5) {
-        div=document.getElementById("preview" + md5);
+        var div=document.getElementById("preview" + md5);
         deleteNode(div);
     }
 
