@@ -23,13 +23,15 @@ var zJSON=function() {
         var http=new XMLHttpRequest();
         resp = response;
         if (object=='locationLookup') {
-            var url="service/locationLookup.php?search=" + escape(search);
+            var url="service.php?_action=locationLookup&search=" + escape(search);
         } else if (object=='photoData') {
-            var url="service/photoData.php?photoId=" + escape(search);
+            var url="service.php?_action=photoData&photoId=" + escape(search);
         } else if (object=='search') {
-            var url="service/search.php" + search;
+            var url="service.php?_action=search&" + search;
         } else if (object=='photoPeople') {
-            var url="service/photoPeople.php?" + search;
+            var url="service.php?_action=photoPeople&" + search;
+        } else if (object=='translation') {
+            var url="service.php?_action=translation&" + search;
         } else {
             return;
         }
@@ -40,7 +42,7 @@ var zJSON=function() {
             http.onreadystatechange=function() {
                httpResponse(http, object);
             };
-            http.send(null);
+            http.send();
         } else {
             // try again in 500 ms
             clearTimeout(retry);
