@@ -23,30 +23,17 @@
 
 use conf\conf;
 
-use permissions\controller as permissionsController;
-
-use template\block;
-use template\form;
-use template\template;
+use permissions\controller;
 
 use web\request;
-
+use web\redirect;
 
 require_once "include.inc.php";
 
 if (!user::getCurrent()->isAdmin()) {
-    redirect("zoph.php");
+    redirect::redirect("zoph.php", "Admin user required");
 }
 
-$controller = new permissionsController(request::create());
-
-$redirect="zoph.php";
-if ($controller->getView() == "group") {
-    $group=$controller->getObject();
-    $redirect = "group.php?_action=edit&group_id=" . $group->getId();
-} else if ($controller->getView() == "album") {
-    $album=$controller->getObject();
-    $redirect = "album.php?_action=edit&album_id=" . $album->getId();
-}
-
-redirect($redirect);
+$controller = new controller(request::create());
+$view=$controller->getView();
+$view->display();
