@@ -26,12 +26,5 @@ require_once "include.inc.php";
 
 $request = web\request::create();
 $controller = new photos\controller($request);
-$view = new photos\view\display($request, $controller->getParams());
-$view->setPhotos($controller->getPhotos());
-$view->setDisplay($controller->getDisplay());
-$view->setLightbox($controller->getLightbox());
-$extrastyle = $controller->getParams()->getStyle();
-$title = $view->getTitle();
-require_once "header.inc.php";
-echo $view->view();
-require_once "footer.inc.php";
+$view = $controller->getView();
+$view->display();
