@@ -22,16 +22,11 @@
  */
 
 use conf\conf;
-
-if (!is_callable("finfo_file")) {
-    log::msg("fileinfo PHP extension is missing", log::FATAL);
-    die();
-}
-
-if (!file_exists(conf::get("path.magic")) && strlen(conf::get("path.magic"))>0) {
-    log::msg(conf::get("path.magic") . " does not exist. Set the location of your " .
-        "magic file in admin -> config to your MIME magic file.", log::FATAL);
-    die();
+use requirements\check;
+use requirements\view\failed;
+use web\request;
+if (basename($_SERVER["SCRIPT_NAME"]) == "css.php") {
+    return;
 }
 
 if (!ini_get("date.timezone")) {
@@ -41,12 +36,16 @@ if (!ini_get("date.timezone")) {
     date_default_timezone_set($tz);
 }
 
-ini_set("magic_quotes_sybase", false);
-ini_set("magic_quotes_runtime", false);
-ini_set("magic_quotes_gpc", false);
 ini_set("session.use_only_cookies", true);
 
-if (PHP_VERSION_ID < 50500) {
-    die("You should run at least PHP 5.5 to use Zoph");
-}
+$check = new check();
+$check->doChecks();
 
+$status = $check->getStatus();
+if (!$status) {
+    $view = new failed(request::create());
+    $view->addRequirements($check);
+    $view->display();
+
+    exit;
+}
