@@ -28,10 +28,5 @@ use slideshow\controller;
 require_once "include.inc.php";
 $request = request::create();
 $controller = new controller($request);
-
-$view = new slideshow\view\display($request);
-$title = $view->getTitle();
-
-require_once "header.inc.php";
-echo $view->view();
-require_once "footer.inc.php";
+$view = $controller->getView();
+$view->display();
