@@ -24,15 +24,15 @@ if (!ZOPH) { die("Illegal call"); }
 <nav class="calendarhdr">
   <ul>
     <li class="prev">
-      <a href="<?php echo $tpl_prev ?>">
+      <a href="<?= $tpl_prev ?>">
         <?= translate("Prev") ?>
       </a>
     </li>
     <li class="date">
-      <h2><?php echo $tpl_header ?></h2>
+      <h2><?= $tpl_header ?></h2>
     </li>
     <li class="next">
-      <a href="<?php echo $tpl_next ?>">
+      <a href="<?= $tpl_next ?>">
         <?= translate("Next") ?>
       </a>
     </li>
@@ -40,15 +40,15 @@ if (!ZOPH) { die("Illegal call"); }
 </nav>
 <ul class="thumbs calendar">
   <?php foreach ($tpl_days as $day): ?>
-    <li class="thumb_album <?php echo $day["class"] ?>">
+    <li class="thumb_album <?= $day["class"] ?>">
       <?php if ($day["link"]): ?>
-        <a href="<?php echo ($day["link"]) ?>">
+        <a href="<?= $day["link"] ?>">
       <?php endif; ?>
       <?php if ($day["photo"]): ?>
         <?= $day["photo"] ?>
       <?php endif; ?>
       <div class="name">
-        <?php echo $day["date"] ?>
+        <?= $day["date"] ?>
         <?php if ($day["photocount"] > 0) : ?>
           <span class="photocount">
             (<?= $day["photocount"] ?>)
