@@ -30,7 +30,7 @@ if (!ZOPH) {
     <table class="permissions">
         <caption>
             <?= $tpl_edit == "album" ? translate("Group permissions") : translate("Album permissions") ?>
-        </caption> 
+        </caption>
         <col class="col1"><col class="col2"><col class="col3"><col class="col4">
         <tr>
             <td></td>
@@ -66,7 +66,7 @@ if (!ZOPH) {
                 </td>
             <?php endif ?>
             <td>
-                <?php echo template::createYesNoPulldown("writable_all", "0") ?>
+                <?php echo template::createYesNoDropdown("writable_all", "0") ?>
             </td>
         </tr>
         <tr>
@@ -75,10 +75,10 @@ if (!ZOPH) {
             <td>
                 <?php if ($tpl_edit == "album"): ?>
                     <input type="hidden" name="group_id_new" value="<?= $tpl_id ?>">
-                    <?= template::createPulldown("album_id_new", "", album::getTreeSelectArray()) ?>
+                    <?= template::createDropdown("album_id_new", "", album::getTreeSelectArray()) ?>
                 <?php else: ?>
                     <input type="hidden" name="album_id_new" value="<?= $tpl_id ?>">
-                    <?= template::createPulldown("group_id_new", "", group::getSelectArray()) ?>
+                    <?= template::createDropdown("group_id_new", "", group::getSelectArray()) ?>
                 <?php endif ?>
             </td>
             <td>
@@ -90,11 +90,11 @@ if (!ZOPH) {
                 </td>
             <?php endif ?>
             <td>
-                <?php echo template::createYesNoPulldown("writable_new", "0") ?>
+                <?php echo template::createYesNoDropdown("writable_new", "0") ?>
             </td>
             <?php if ($tpl_edit == "album"): ?>
                 <td>
-                    <?php echo template::createYesNoPulldown("subalbums_new", "0") ?>
+                    <?php echo template::createYesNoDropdown("subalbums_new", "0") ?>
                 </td>
             <?php endif ?>
         </tr>
@@ -114,19 +114,19 @@ if (!ZOPH) {
                 <td>
                     <input type="hidden" name="album_id__<?= $perm->get($tpl_edit_id) ?>" value="<?= $perm->get("album_id") ?>">
                     <input type="hidden" name="group_id__<?= $perm->get($tpl_edit_id) ?>" value="<?= $perm->get("group_id") ?>">
-                    <?= template::createInput("access_level__" . $perm->get($tpl_edit_id), $perm->get("access_level"), 4) ?>
+                    <?= template::createInputNumber("access_level__" . $perm->get($tpl_edit_id), $perm->get("access_level"), null, 1, 10) ?>
                 </td>
                 <?php if ($tpl_watermark): ?>
                     <td>
-                        <?= template::createInput("watermark_level__" . $perm->get($tpl_edit_id), $perm->get("watermark_level"), 4) ?>
+                        <?= template::createInputNumber("watermark_level__" . $perm->get($tpl_edit_id), $perm->get("watermark_level"), null, 1, 10) ?>
                      </td>
                 <?php endif ?>
                 <td>
-                    <?= template::createYesNoPulldown("writable__" . $perm->get($tpl_edit_id), $perm->get("writable")) ?>
+                    <?= template::createYesNoDropdown("writable__" . $perm->get($tpl_edit_id), $perm->get("writable")) ?>
                 </td>
                 <?php if ($tpl_edit == "album"): ?>
                     <td>
-                        <?= template::createYesNoPulldown("subalbums__" . $perm->get($tpl_edit_id), $perm->get("subalbums")) ?>
+                        <?= template::createYesNoDropdown("subalbums__" . $perm->get($tpl_edit_id), $perm->get("subalbums")) ?>
                     </td>
                 <?php endif ?>
             </tr>
