@@ -27,7 +27,7 @@ if (!ZOPH) {
 ?>
 <li class="exif">
     <div class="tab">
-      <img src="<?php echo template::getImage("icons/exif.png") ?>">
+      <img alt="exif" src="<?php echo template::getImage("icons/exif.png") ?>">
     </div>
     <div class="contents">
         <h1><?= translate("Full EXIF details", 0) ?></h1>
