@@ -26,7 +26,7 @@ if (!ZOPH) {
     <?= $tpl_warning ?? "" ?>
     <form enctype="multipart/form-data" <?= isset($tpl_class) ? "class=\"" . $tpl_class . "\"" : "" ?>
         action="<?= $tpl_formAction; ?>" method="POST"
-        onSubmit="<?= $tpl_onsubmit; ?>">
+        "onSubmit="<?= $tpl_onsubmit ?? "" ?>">
         <input type="hidden" name="_action" value="<?= $tpl_action ?>">
         <?= $this->displayBlocks(); ?>
         <input type="submit" class="<?= $tpl_submit_class ?? '' ?>" value="<?= $tpl_submit ?>">
