@@ -29,7 +29,7 @@ if (!ZOPH) {
         <?= $tpl_label ?>
     </label>
 <?php endif; ?>
-<input type="password" name="<?= $tpl_name ?>" size="<?= $tpl_size ?>">
+<input id="<?= $tpl_name ?>" type="password" name="<?= $tpl_name ?>" size="<?= $tpl_size ?>">
 <?php if (!empty($tpl_hint)): ?>
     <span class="inputhint">
         <?php echo $tpl_hint ?>
