@@ -29,7 +29,18 @@ if (!ZOPH) {
         <?= $tpl_label ?>
     </label>
 <?php endif; ?>
-<input id="<?= $tpl_name ?>" type="text" name="<?= $tpl_name ?>" maxlength="<?= $tpl_maxlength ?>" size="<?= $tpl_size ?>" value="<?= $tpl_value ?>">
+<input
+    id="<?= $tpl_name ?>"
+    type="<?= $tpl_type ?>"
+    name="<?= $tpl_name ?>"
+    maxlength="<?= $tpl_maxlength ?>"
+    size="<?= $tpl_size ?>"
+    value="<?= $tpl_value ?>"
+    <?php if (in_array($tpl_type, [ "number", "range" ])): ?>
+        min="<?= $tpl_min ?>"
+        max="<?= $tpl_max ?>"
+    <?php endif; ?>
+    >
 <?php if (!empty($tpl_hint)): ?>
     <span class="inputhint">
         <?php echo $tpl_hint ?>
