@@ -25,7 +25,7 @@ if (!ZOPH) { die("Illegal call"); }
 <form id="ratingform" method="POST">
     <input type="hidden" name="_action" value="rate">
     <input type="hidden" name="photo_id" value="<?= $tpl_photoId ?>">
-    <?= $tpl_ratingPulldown ?>
+    <?= $tpl_ratingDropdown ?>
     <input type="submit" id="ratingsubmit" name="_button" value="<?= translate("rate", 0) ?>">
 </form>
 <script type="text/javascript">
