@@ -20,5 +20,4 @@
  */
 if (!ZOPH) { die("Illegal call"); }
 ?>
-<img src="<?php echo $tpl_src ?>" class="<?php echo $tpl_class ?>"
-    <?php echo $tpl_size ?> alt="<?php echo $tpl_alt ?>">
+<img src="<?= $tpl_src ?>" class="<?= $tpl_class ?>" <?= $tpl_size ?> alt="<?= $tpl_alt ?>" <?= isset($tpl_data_photo_id) ? "data-photo-id =" . $tpl_data_photo_id : "" ?>>
