@@ -22,7 +22,7 @@
 if (!ZOPH) { die("Illegal call"); }
 ?>
 
-<a href="<?php echo $tpl_href ?>" target="<?php echo $tpl_target ?>">
-    <?php echo $tpl_link ?>
+<a href="<?= $tpl_href ?>" target="<?= $tpl_target ?? "" ?>">
+    <?= $tpl_link ?>
 </a>
 
