@@ -32,8 +32,8 @@ if (!ZOPH) { die("Illegal call"); }
         // Add markers:
         <?php foreach ($this->getMarkers() as $m): ?>
             zMaps.createMarker("<?= $m->lat ?>","<?= $m->lon ?>",
-                icons["<?= $m->icon ?>"], '<?= str_replace("'", "\\'", $m->title) ?>',
-                '<?= str_replace("'", "\\'", $m->quicklook) ?>');
+                icons["<?= $m->icon ?>"], '<?= str_replace("'", "\\'", empty($m->title) ? "" : $m->title) ?>',
+                '<?= str_replace("'", "\\'", empty($m->quicklook) ? "" : $m->quicklook) ?>');
         <?php endforeach ?>
     <?php endif ?>
 
