@@ -26,7 +26,7 @@ if (!ZOPH) {
 }
 ?>
 
-<div class="message <?= $tpl_class ?>">
+<div id="<?= $tpl_id ?? "" ?>" class="message <?= $tpl_class ?>">
     <img alt="<?= $tpl_class ?>" class='icon' src='<?php echo template::getImage("icons/" . $tpl_class . ".png") ?>'>
     <?php if (isset($tpl_title)): ?>
         <h1><?= $tpl_title ?></h1>
@@ -35,5 +35,3 @@ if (!ZOPH) {
     <br>
     <?= $this->getActionlinks() ?>
 </div>
-
-
