@@ -23,9 +23,9 @@ if (!ZOPH) { die("Illegal call"); }
 ?>
 <ul class="actionlink letter">
     <?php for ($l = "a"; $l != "aa"; $l++): ?>
-        <li><a href="people.php?_l=<?= $l ?>" <?= ($l == $tpl_l) ? "class=\"selected\"" : "" ?>"><?= $l ?></a></li>
+        <li><a href="person.php?_action=people&_l=<?= $l ?>" <?= ($l == $tpl_l) ? "class=\"selected\"" : "" ?>><?= $l ?></a></li>
     <?php endfor ?>
-    <li><a href="people.php?_l=no%20last%20name"><?php echo translate("no last name") ?></a></li>
-    <li><a href="people.php?_l=all"><?php echo translate("all") ?></a></li>
+    <li><a href="person.php?_action=people&_l=no%20last%20name"><?= translate("no last name") ?></a></li>
+    <li><a href="person.php?_action=people&_l=all"><?= translate("all") ?></a></li>
 </ul>
 
