@@ -24,8 +24,7 @@ if (!ZOPH) {
 }
 ?>
     <form class="search" enctype="multipart/form-data" action="search.php" method="POST">
-        <input type="hidden" name="_action" value="search">
         <?= $this->displayBlocks(); ?>
-        <input type="submit" value="<?= translate("search") ?>">
+        <input type="submit" name="_action" value="<?= translate("search") ?>">
     </form>
 
