@@ -22,7 +22,11 @@
 if (!ZOPH) { die("Illegal call"); }
 ?>
 
+<br>
 <div class="smileys">
+    <?php if ($tpl_title): ?>
+        <h2><?= $tpl_title ?></h2>
+    <?php endif ?>
     <?php foreach ($tpl_smileys as $smiley): ?>
         <div>
             <?= $smiley ?>
