@@ -25,13 +25,13 @@ if (!ZOPH) {
     die("Illegal call");
 }
 ?>
-    <form enctype="multipart/form-data" action="<?php echo $tpl_action; ?>" method="POST"
-        onSubmit="<?php echo $tpl_onsubmit; ?>">
-        <input type="hidden" name="<?php echo $tpl_progress ?>"
-            id="upload_<?php echo $tpl_num; ?>"
-            value="<?php echo $tpl_upload_num ?>">
+    <form id="upload" enctype="multipart/form-data" action="<?php echo $tpl_action; ?>" method="POST">
         <input type="hidden" name="_action" value="upload">
-        <input type="file" name="file">
-        <input type="submit" name="submit" value="<?php echo translate("import", false); ?>">
+        <input id="fileselect" type="file" name="files[]" multiple="multiple">
+        <div id="drop" class="drop"><?= translate("Drop files here", false) ?></div>
+        <button id="uploadSubmit" type="submit" name="submit"><?php echo translate("upload", false); ?></button>
     </form>
+    <div id="uploadResults">
+    </div>
+
 
