@@ -81,12 +81,39 @@ h1 .actionlink {
     font-size: 50%;
 }
 
+tt {
+    background: #dddddd;
+    border: 1px solid #aaaaaa;
+    border-radius: 3px;
+    padding: 1px 5px;
+    box-shadow: 2px 2px 2px rgba(0,0,0,0.1);
+}
+
 /* Unordered list */
 ul  {
     padding-left: 1em;
     margin: 0.5em 1em 1em 1em;
 }
 
+section {
+    box-sizing: border-box;
+    margin: 2% 2% 4em 2%;
+    width: 96%;
+}
+
+section > h1 {
+    box-sizing: border-box;
+    margin: 2em 0;
+    width: 100%;
+}
+section div {
+    margin: 1rem 0;
+}
+
+section.install div {
+    font-size: 1.5rem;
+}
+
 ul.thumbs {
     clear: both;
     list-style: none;
@@ -320,24 +347,13 @@ form.viewsettings select#parent_place_id {
     width: 10em;
 }
 
-/* Form to add a page to a pageset */
 form.addpage {
-    width: auto;
-    text-align: right;
-}
-form.addpage input[type="submit"]   {
-    display: inline;
-    margin: 15px;
-    vertical-align: middle;
-}
-form.addpage select {
-    display: inline;
-    vertical-align: middle;
+    margin-top: 1.5rem;
 }
+
 form.addpage label {
-    vertical-align: middle;
-    float: none;
-    display: inline;
+    width: auto;
+    margin-left: 0;
 }
 
 form.grouppermissions,
@@ -461,6 +477,9 @@ nav.menu ul li a {
 nav.menu ul li.selected > a {
     color: <?= colorScheme::getColor("selected_tab_font_color") ?>;
 }
+nav.menu ul li.selected > a:hover {
+    color: <?= colorScheme::getColor("selected_tab_font_color") ?>;
+}
 
 nav.menu ul li a:hover {
     color: <?= colorScheme::getColor("text_color") ?>;
@@ -504,7 +523,7 @@ ul.breadcrumbs li a {
 }
 
 /* Main page */
-.main, .page, div.map, div#selection, div.related, div.permissions  {
+.main, div.page, div.map, div#selection, div.related, div.permissions, div.comments  {
     background: <?= colorScheme::getColor("table_bg_color") ?>;
     font-size: medium;
     width: 100%;
@@ -521,7 +540,8 @@ ul.breadcrumbs li a {
    border radius and add a small margin */
 .main + .page,
 .page + .main,
-.main + .permissions {
+.main + .permissions,
+.main + .comments {
     border-radius: 5px;
     margin-top: 10px;
 }
@@ -555,6 +575,10 @@ div#selection {
     z-index: 6;
 }
 
+div#selection div.thumbnail {
+    float: left;
+}
+
 .leaflet-control-layers-base label {
     text-align: left;
 }
@@ -567,7 +591,7 @@ div.minimap {
 }
 
 /* explanation of the config item on the config page */
-div.main#config .desc {
+form.config .desc {
     clear: both;
     width: 50%;
     color: <?= colorScheme::getColor("title_font_color") ?>;
@@ -579,14 +603,14 @@ div.main#config .desc {
     border-radius: 4px;
 }
 
-div.main#config div.confGroup > .desc {
+form.config div.confGroup > .desc {
     color: <?= colorScheme::getColor("text_color") ?>;
     background: none;
     margin-left: 0;
     width: 98%;
 }
 
-div.main#config h2 {
+form.config h2 {
     position: relative;
     left: -11px;
     clear: both;
@@ -598,15 +622,15 @@ div.main#config h2 {
     width: 100%;
 }
 
-div.main#config input[type="checkbox"] {
+form.config input[type="checkbox"] {
     margin: 7px;
 }
 
-div.main#config input.reset {
+form.config input.reset {
     float: right;
 }
 
-div.main#config input.reset + span {
+form.config input.reset + span {
     margin-top: 2px;
     height: 1em;
     overflow: hidden;
@@ -616,8 +640,8 @@ div.main#config input.reset + span {
     opacity: 0;
 }
 
-div.main#config input.reset:hover + span,
-div.main#config input.reset:checked + span {
+form.config input.reset:hover + span,
+form.config input.reset:checked + span {
     opacity: 1;
 }
 
@@ -795,7 +819,10 @@ table.reports {
     padding: 10px 5px 20px 5px;
 }
 
-table#users th,
+table.pages th,
+table.pagesets th,
+table.sets th,
+table.users th,
 table.reports th {
     text-align: left;
     color: <?= colorScheme::getColor("title_font_color") ?>;
@@ -803,13 +830,21 @@ table.reports th {
     font-weight: normal;
 }
 
-table.pages, table.pagesets {
+table.pages,
+table.pagesets,
+table.sets {
     width: 100%;
 }
 
 div.smileys {
+    overflow: hidden;
     border: 1px solid black;
-    clear: right;
+    clear: both;
+    background: <?= colorScheme::getColor("title_bg_color") ?>;
+    padding: 0.5rem 1rem;
+    margin: 1rem 0.5rem;
+    box-shadow: 5px 5px 5px rgba(0,0,0,0.4);
+    border-radius: 0.5rem;
 }
 
 div.smileys div {
@@ -841,8 +876,7 @@ form.search input[type="checkbox"] {
     margin: 0 0 0 5px;
 }
 
-form.search input[type="checkbox"] + label,
-table#search input[type="checkbox"] + label {
+form.search input[type="checkbox"] + label {
     float: none;
     display: inline;
     position: relative;
@@ -857,7 +891,7 @@ table#search input[type="checkbox"] + label {
 
 div.searchTerm {
     display: flex;
-    align-items: top;
+    align-items: start;
     clear: both;
 }
 
@@ -901,7 +935,7 @@ div.searchTerm input[type="checkbox"] {
 }
 
 div.searchLatLon {
-    line-height: 1.5em; !important
+    line-height: 1.5em;
 }
 
 span.photocount {
@@ -920,6 +954,14 @@ ul.actionlink {
     clear: right;
 }
 
+div.dragdrop ul.actionlink {
+    float: none;
+    width: 2.5rem;
+    padding: 0;
+    grid-column-start: 3;
+    text-align: center;
+}
+
 ul.letter {
     text-align: center;
     border: 1px solid black;
@@ -931,16 +973,19 @@ ul.letter {
 ul.actionlink li:before {
     content: ' | ';
     color: <?= colorScheme::getColor("title_font_color") ?>;
+    opacity: 0.4;
 }
 
 ul.actionlink li:first-child:before {
     content: ' [ ';
     color: <?= colorScheme::getColor("title_font_color") ?>;
-    }
+    opacity: 0.4;
+}
 
 ul.actionlink li:last-child:after {
     content: ' ] ';
     color: <?= colorScheme::getColor("title_font_color") ?>;
+    opacity: 0.4;
 }
 
 ul.actionlink li {
@@ -1070,42 +1115,44 @@ table.permissions input {
     float: none;
 }
 
-nav.calendarhdr ul,
-nav.photohdr ul {
-    display: flex;
-    justify-content: space-between;
-    margin: 10px 0;
-}
-
 nav.calendarhdr ul {
+    display: grid;
     margin: 10px 30px;
+    grid-template-columns: 1fr 1fr 3fr 1fr 1fr;
 }
 
-nav.calendarhdr ul li {
-    padding: 10px;
-    width: 50px;
+nav.photohdr ul {
+    display: grid;
+    margin: 10px 0;
+    grid-template-columns: repeat(5,1fr);
 }
+
 nav.calendarhdr ul li a:hover {
     text-decoration: underline;
 }
-nav.photohdr ul li {
-    width: 50px;
+
+nav.calendarhdr ul li.prev,
+nav.photohdr ul li.prev {
+    grid-column-start: 1;
+}
+nav.calendarhdr ul li.date,
+nav.photohdr ul li.up {
+    grid-column-start: 3;
+}
+nav.calendarhdr ul li.next,
+nav.photohdr ul li.next {
+    grid-column-start: 5;
 }
 
-nav.calendarhdr ul li.date {
-    padding: 2px;
-    width: 400px;
+nav.calendarhdr ul li a {
+    margin: 1em;
 }
+
 nav.calendarhdr ul li.date h2 {
     text-align: center;
     font-size: xx-large;
     font-weight: bold;
 }
-
-nav.photohdr ul li:empty {
-    background: transparent;
-}
-
 div.photodata {
     text-align: center;
     width: 100%;
@@ -1412,7 +1459,7 @@ div.main:fullscreen div.slide-annotate {
 
 @media only screen and (max-width: 1024px) {
     div.main:fullscreen div.slide-annotate {
-        font-size:20px
+        font-size: 20px;
         width: 100px;
     }
 }
@@ -1766,7 +1813,7 @@ div.formtext {
     padding: 15px;
 }
 
-div.editchoice  {
+fieldset.editchoice  {
     position: relative;
     z-index: 5;
     vertical-align: top;
@@ -1777,18 +1824,58 @@ div.editchoice  {
     float: left;
     width: 10em;
 }
+fieldset.editchoice > legend {
+    display: none;
+}
 
+div.thumbnails {
+    display: grid;
+    row-gap: 60px;
+}
 /* Thumbnail photo */
 div.thumbnail   {
     text-align: center;
     vertical-align: top;
     width: <?= THUMB_SIZE ?>px;
     height: <?= THUMB_SIZE ?>px;
-    float:left;
     margin: 2px;
     padding: 5px;
 }
 
+div.dragdrop {
+    display: grid;
+    grid-template-rows: 1fr 6fr;
+    grid-template-columns: 2fr 3fr 2fr;
+}
+
+div.dragdrop img.thumb {
+    grid-row-start: 2;
+
+}
+
+div.dropzone {
+    margin: 0;
+    grid-row-start: 2;
+}
+div.dropzone-active {
+    grid-row-start: 2;
+    width: <?= THUMB_SIZE ?>px;
+    padding: 2em;
+    outline-offset: -2em;
+    outline: 1px dashed black;
+}
+
+div.dropzone-active:nth-child(2) {
+    margin: -2em 2em -2em 0em;
+}
+
+img.thumb + div.dropzone-active {
+    margin-right: 2em;
+}
+div.dropzone-active:last-child {
+    margin: -2em 0em -2em 2em;
+}
+
 div.comment {
     border: 1px solid <?= colorScheme::getColor("table_border_color") ?>;
     background: transparent;
@@ -1835,6 +1922,30 @@ br.noclear {
     float: left;
 }
 
+ul.featured-images {
+    list-style: none;
+    display: grid;
+    grid-template-columns: repeat(10,1fr);
+    column-gap: 20px;
+    min-height: <?= THUMB_SIZE ?>px;
+}
+
+ul.featured-images:empty {
+    background: rgba(0,0,0,0.05);
+}
+
+ul.featured-images.thumbs {
+    padding-bottom: 5px;
+}
+
+div.featured > a {
+    display: block;
+    width: 100%;
+    text-align: right;
+    margin: 0 1em 2em auto;
+}
+
+
 /* Person / place in the list of persons / places */
 .person, .place, .showattr {
     text-align: left;
@@ -1961,7 +2072,7 @@ fieldset.geotag  {
     border: 1px solid <?= colorScheme::getColor("page_bg_color") ?>;
 }
 
-fieldset.members {
+fieldset.addRemove {
     clear: both;
     margin: 20px 20px 20px 12em;
     padding: 1em;
@@ -1979,10 +2090,10 @@ fieldset.map {
     position: relative;
 }
 
-fieldset.editphotos legend,
+fieldset.editphotos > legend,
 fieldset.map legend,
 fieldset.geotag legend,
-fieldset.members legend {
+fieldset.addRemove legend {
     clear: both;
     display: block;
     margin-left: 2em;
@@ -1993,7 +2104,7 @@ fieldset.members legend {
     background: <?= colorScheme::getColor("title_bg_color") ?>;
 }
 
-fieldset.members legend {
+fieldset.addRemove legend {
     padding: 0.3em 1em;
     margin-left: 0.5em;
 
@@ -2112,6 +2223,7 @@ div#passwordchange input[type="password"]   {
 }
 
 select,
+input[type="email"],
 input[type="text"],
 input[type="time"],
 input[type="date"],
@@ -2160,7 +2272,7 @@ form.geotag fieldset.checkboxlist select {
     float: none;
 }
 
-table#users,
+table.users,
 table.credits {
     width: 100%;
 }
@@ -2175,7 +2287,7 @@ table.credits th {
 
 }
 
-table#users td,
+table.users td,
 table.credits td {
     padding: 2px;
     vertical-align: top;
@@ -2195,12 +2307,6 @@ table#zophinfo td {
     width: 20%;
 }
 
-div#relation {
-    margin-left: auto;
-    margin-right: auto;
-    width: 50%;
-}
-
 div#rotate select,
 div#rotate input[type="submit"] {
     font-weight: normal;
@@ -2253,6 +2359,12 @@ div.page div.background {
     width: 100%;
 }
 
+div.relation {
+    margin-left: auto;
+    margin-right: auto;
+    width: 50%;
+}
+
 /* Styles for the import page */
 div.import_thumbs,
 div.import_uploads,
@@ -2271,10 +2383,13 @@ div.import_thumbs {
     display: none;
 }
 
+div.relation div.thumbnail,
+div.related div.thumbnail,
 div.import_thumbs div.thumbnail {
     min-height: <?= THUMB_SIZE + 40 ?>px;
     height: auto;
     overflow: hidden;
+    float: left;
 }
 
 div.import_thumbs img {
@@ -2300,7 +2415,7 @@ div.import_thumbs ul.categories li.unknown {
     background: #ffbbbb;
 }
 
-div.import textarea { /// CHECK
+div.import textarea {
     width: 60%;
 }
 
@@ -2331,7 +2446,7 @@ div.upload {
     padding: 0.5em;
     border-radius: 5px;
     box-shadow: 3px 3px 5px rgba(0,0,0, 0.5);
-    
+
 }
 
 div#uploadResults div.uploadError {
@@ -2465,7 +2580,7 @@ div.preview {
 
 ul.tabs {
     list-style: none;
-    float:right;
+    float: right;
     margin: 0 -10px 0 -40px;
     width: 40px;
     height: 0;
@@ -2480,7 +2595,6 @@ ul.tabs > li {
     height: 55px;
     width: 40px;
     clear: both;
-    overflow: hiddden;
     transition: width 700ms ease-out 200ms;
 
 }
@@ -2578,8 +2692,8 @@ ul.calendar li.photos:hover {
 .message  {
     width: 80%;
     text-align: center;
-    margin: 10px auto;
-    padding:12px;
+    margin: 2em auto 4em;
+    padding: 2em;
     clear: both;
     border-radius: 10px;
     box-shadow: 5px 5px 5px rgba(0,0,0,0.4);
@@ -2603,7 +2717,7 @@ div.message div.messageText h1 {
     background: transparent;
     text-align: center;
     font-size: large;
-    padding: none;
+    padding: 0;
     box-shadow: none;
     margin: 0 0 1em 0;
     color: inherit;
@@ -2650,7 +2764,7 @@ div.message ul.actionlink li::before {
 .version    {
     text-align: center;
     font-size: small;
-    margin-bottom: 2px;
+    margin: 30px auto 2px auto;
 }
 
 
@@ -2758,6 +2872,14 @@ div.result div.error:empty {
     display: none;
 }
 
+input[type=submit].big {
+    position: relative;
+    width: 90%;
+    left: 15px;
+    height: 3em;
+}
+
+input[type=submit].big,
 a.button {
     font-size: x-large;
     font-weight: bold;
@@ -2771,6 +2893,7 @@ a.button {
    vertical-align: middle;
 }
 
+input[type=submit].big:hover,
 a.button:hover {
     position: relative;
     left: 5px;
@@ -2778,6 +2901,7 @@ a.button:hover {
     box-shadow: 5px 5px 5px rgba(0,0,0,0.8);
 }
 
+input[type=submit].big.green,
 .green {
    border-top: 1px solid #97f7a4;
    background-image: linear-gradient(rgba(62,156,74,90%), rgba(101,212,115,70%));
@@ -2785,6 +2909,7 @@ a.button:hover {
    color: white;
 }
 
+input[type=submit].big.green:hover,
 .green:hover {
    border-top-color: #287832;
    background: #287832;
@@ -2804,4 +2929,74 @@ a.button:hover {
     }
 }
 
+iframe.download {
+    border: none;
+    width: 100%;
+    min-height: 4em;
+}
+
+div.install ul {
+    display: flex;
+    flex-wrap: nowrap;
+    padding: 2em 0;
+}
+
+div.install ul li {
+    background: <?= colorScheme::getColor("selected_tab_bg_color") ?>;
+    list-style: none;
+    aspect-ratio: 1;
+    border: 1px solid black;
+    margin: 5px;
+    border-radius: 5px;
+    box-shadow: 5px 5px 5px rgba(0,0,0,0.2);
+}
+
+div.install ul li.selected {
+    background: <?= colorScheme::getColor("tab_bg_color") ?>;
+}
+
+div.install ul li.selected ~ li img {
+    filter: grayscale(100%) opacity(40%);
+}
+
+div.install ul li img {
+    filter: revert;
+    width: 70%;
+    height: 70%;
+    margin: 15%;
+}
+
+a.button.requirements,
+a.button.install {
+    background: <?= colorScheme::getColor("tab_bg_color") ?>;
+
+}
+
+table.requirements {
+    border: 1px solid rgba(0,0,0,0.3);
+    background: white;
+    box-shadow: 5px 5px 5px rgba(0,0,0,0.2);
+    margin: 2em auto;
+    border-radius: 7px;
+    border-spacing: 0;
+    padding: 5px;
+    border-collapse: separate;
+}
+
+table.requirements th,
+table.requirements td {
+    border: none;
+    padding: 0.5em;
+    font-size: 1.3rem;
+    text-align: left;
+    vertical-align: middle;
+}
+
+table.requirements td img {
+    width: 48px;
+    height: 48px;
+}
+
+<?php require_once("alert.css.php"); ?>
+
 /* vim: set syntax=css: */
