@@ -17,6 +17,7 @@
  *
  * @author Jeroen Roos
  * @package ZophTemplates
+ *
  */
 if (!ZOPH) {
     die("Illegal call");
@@ -25,16 +26,15 @@ if (!ZOPH) {
 
 <!DOCTYPE html>
 <html lang="<?= $tpl_lang ?>">
-<head>
-<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
-<title><?= $tpl_title ?></title>
-</head>
-<body>
-<h1><?= $tpl_title ?></h1>
-<div class="error">
-<?= $tpl_message ?>
-<?= $this->getActionLinks() ?>
-</div>
-</body>
+    <head>
+        <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
+        <?php foreach ($tpl_css as $css): ?>
+            <link type='text/css' rel="stylesheet" href="<?= $css ?>">
+        <?php endforeach ?>
+        <title><?= $tpl_title ?></title>
+    </head>
+    <body>
+        <h1><?= $tpl_title ?></h1>
+        <?= $this->displayBlocks() ?>
+    </body>
 </html>
-
