@@ -116,39 +116,11 @@ div.logon input[type=submit] {
     height: 35px;
     border-radius: 0 0 15px 15px;
 }
-    
+
 div.logon input[type=submit]:hover {
     background: #bbbbbb;
 }
 
-div.error,
-div.warning {
-    position: relative;
-    top: 20px;
-    margin:    0px auto 20px auto;
-    padding: 1em 2em 1em 100px;
-    background: white;
-    width: 400px;
-    height: 40px;
-    border-radius: 15px;
-    opacity: 0.95;
-    box-shadow: 5px 5px 5px 5px rgba(0,0,0,0.5);
-    font-size: 14px;
-    font-weight: bold;
-    text-align: center;
-    color: black;
-}
-
-div.error {
-    background: url("<?= template::getImage("icons/error.png") ?>") no-repeat #ffbbbb 15px;
-}
-
-div.warning {
-    background: url("<?= template::getImage("icons/warning.png") ?>") no-repeat #ffffbb 15px;
-}
-
-div.error:empty,
-div.warning:empty {
-    display: none;
-}
+<?php require_once("alert.css.php"); ?>
 
+/* vim: set syntax=css: */
