@@ -22,29 +22,16 @@
  * @author Jeroen Roos
  */
 
-use conf\conf;
 use upgrade\controller;
 use web\request;
+use web\redirect;
 
 require_once "include.inc.php";
-$title = translate("Zoph Upgrade");
 
 if (!$user->isAdmin()) {
-    redirect("zoph.php");
+    redirect::redirect("zoph.php", "Admin user required");
 }
 
 $ctrl = new controller(request::create());
 $view = $ctrl->getView();
-
-$headers = $view->getHeaders();
-if (is_array($headers)) {
-    foreach ($headers as $header) {
-        header($header);
-    }
-    echo $view->view();
-} else {
-    $title = $view->getTitle();
-    require_once("header.inc.php");
-    echo $view->view();
-    require_once("footer.inc.php");
-}
+$view->display();
